@@ -88,6 +88,8 @@ void up_schedule_sigaction(struct tcb_s *tcb, sig_deliver_t sigdeliver)
 
   if (tcb->xcp.sigdeliver == NULL)
     {
+      tcb->xcp.sigdeliver = sigdeliver;
+
       /* First, handle some special cases when the signal is being delivered
        * to the currently executing task.
        */
@@ -107,6 +109,7 @@ void up_schedule_sigaction(struct tcb_s *tcb, sig_deliver_t sigdeliver)
                */
 
               sigdeliver(tcb);
+              tcb->xcp.sigdeliver = NULL;
             }
 
           /* CASE 2:  We are in an interrupt handler AND the interrupted
@@ -123,8 +126,6 @@ void up_schedule_sigaction(struct tcb_s *tcb, sig_deliver_t sigdeliver)
                * delivered.
                */
 
-              tcb->xcp.sigdeliver          = (void *)sigdeliver;
-
               /* And make sure that the saved context in the TCB is the same
                * as the interrupt return context.
                */
@@ -138,12 +139,12 @@ void up_schedule_sigaction(struct tcb_s *tcb, sig_deliver_t sigdeliver)
 
               CURRENT_REGS                 = (void *)
                                              ((uint32_t)CURRENT_REGS -
-                                              (uint32_t)XCPTCONTEXT_SIZE);
+                                                        XCPTCONTEXT_SIZE);
               memcpy((uint32_t *)CURRENT_REGS, tcb->xcp.saved_regs,
                      XCPTCONTEXT_SIZE);
 
               CURRENT_REGS[REG_SP]         = (uint32_t)CURRENT_REGS +
-                                             (uint32_t)XCPTCONTEXT_SIZE;
+                                                       XCPTCONTEXT_SIZE;
 
               /* Then set up to vector to the trampoline with interrupts
                * disabled.  The kernel-space trampoline must run in
@@ -172,8 +173,6 @@ void up_schedule_sigaction(struct tcb_s *tcb, sig_deliver_t sigdeliver)
            * by the signal trampoline after the signal has been delivered.
            */
 
-          tcb->xcp.sigdeliver        = (void *)sigdeliver;
-
           /* Save the current register context location */
 
           tcb->xcp.saved_regs        = tcb->xcp.regs;
@@ -185,11 +184,11 @@ void up_schedule_sigaction(struct tcb_s *tcb, sig_deliver_t sigdeliver)
 
           tcb->xcp.regs              = (void *)
                                        ((uint32_t)tcb->xcp.regs -
-                                        (uint32_t)XCPTCONTEXT_SIZE);
+                                                  XCPTCONTEXT_SIZE);
           memcpy(tcb->xcp.regs, tcb->xcp.saved_regs, XCPTCONTEXT_SIZE);
 
           tcb->xcp.regs[REG_SP]      = (uint32_t)tcb->xcp.regs +
-                                       (uint32_t)XCPTCONTEXT_SIZE;
+                                                 XCPTCONTEXT_SIZE;
 
           /* Then set up to vector to the trampoline with interrupts
            * disabled.  We must already be in privileged thread mode to be
@@ -219,6 +218,8 @@ void up_schedule_sigaction(struct tcb_s *tcb, sig_deliver_t sigdeliver)
 
   if (!tcb->xcp.sigdeliver)
     {
+      tcb->xcp.sigdeliver = sigdeliver;
+
       /* First, handle some special cases when the signal is being delivered
        * to task that is currently executing on any CPU.
        */
@@ -241,6 +242,7 @@ void up_schedule_sigaction(struct tcb_s *tcb, sig_deliver_t sigdeliver)
                */
 
               sigdeliver(tcb);
+              tcb->xcp.sigdeliver = NULL;
             }
 
           /* CASE 2:  The task that needs to receive the signal is running.
@@ -276,8 +278,6 @@ void up_schedule_sigaction(struct tcb_s *tcb, sig_deliver_t sigdeliver)
                    * been delivered.
                    */
 
-                  tcb->xcp.sigdeliver        = (void *)sigdeliver;
-
                   /* Save the current register context location */
 
                   tcb->xcp.saved_regs        = tcb->xcp.regs;
@@ -289,12 +289,12 @@ void up_schedule_sigaction(struct tcb_s *tcb, sig_deliver_t sigdeliver)
 
                   tcb->xcp.regs              = (void *)
                                                ((uint32_t)tcb->xcp.regs -
-                                                (uint32_t)XCPTCONTEXT_SIZE);
+                                                          XCPTCONTEXT_SIZE);
                   memcpy(tcb->xcp.regs, tcb->xcp.saved_regs,
                          XCPTCONTEXT_SIZE);
 
                   tcb->xcp.regs[REG_SP]      = (uint32_t)tcb->xcp.regs +
-                                               (uint32_t)XCPTCONTEXT_SIZE;
+                                                         XCPTCONTEXT_SIZE;
 
                   /* Then set up vector to the trampoline with interrupts
                    * disabled.  We must already be in privileged thread mode
@@ -318,8 +318,6 @@ void up_schedule_sigaction(struct tcb_s *tcb, sig_deliver_t sigdeliver)
                    * signal has been delivered.
                    */
 
-                  tcb->xcp.sigdeliver       = (void *)sigdeliver;
-
                   /* And make sure that the saved context in the TCB is the
                    * same as the interrupt return context.
                    */
@@ -333,12 +331,12 @@ void up_schedule_sigaction(struct tcb_s *tcb, sig_deliver_t sigdeliver)
 
                   CURRENT_REGS              = (void *)
                                               ((uint32_t)CURRENT_REGS -
-                                               (uint32_t)XCPTCONTEXT_SIZE);
+                                                         XCPTCONTEXT_SIZE);
                   memcpy((uint32_t *)CURRENT_REGS, tcb->xcp.saved_regs,
                          XCPTCONTEXT_SIZE);
 
                   CURRENT_REGS[REG_SP]      = (uint32_t)CURRENT_REGS +
-                                              (uint32_t)XCPTCONTEXT_SIZE;
+                                                        XCPTCONTEXT_SIZE;
 
                   /* Then set up vector to the trampoline with interrupts
                    * disabled.  The kernel-space trampoline must run in
@@ -388,8 +386,6 @@ void up_schedule_sigaction(struct tcb_s *tcb, sig_deliver_t sigdeliver)
            * by the signal trampoline after the signal has been delivered.
            */
 
-          tcb->xcp.sigdeliver        = (void *)sigdeliver;
-
           /* Save the current register context location */
 
           tcb->xcp.saved_regs        = tcb->xcp.regs;
@@ -401,11 +397,11 @@ void up_schedule_sigaction(struct tcb_s *tcb, sig_deliver_t sigdeliver)
 
           tcb->xcp.regs              = (void *)
                                        ((uint32_t)tcb->xcp.regs -
-                                        (uint32_t)XCPTCONTEXT_SIZE);
+                                                  XCPTCONTEXT_SIZE);
           memcpy(tcb->xcp.regs, tcb->xcp.saved_regs, XCPTCONTEXT_SIZE);
 
           tcb->xcp.regs[REG_SP]      = (uint32_t)tcb->xcp.regs +
-                                       (uint32_t)XCPTCONTEXT_SIZE;
+                                                 XCPTCONTEXT_SIZE;
 
           /* Increment the IRQ lock count so that when the task is restarted,
            * it will hold the IRQ spinlock.
