@@ -111,7 +111,7 @@ uint32_t *arm_prefetchabort(uint32_t *regs, uint32_t ifar, uint32_t ifsr)
     {
       _alert("Prefetch abort. PC: %08x IFAR: %08x IFSR: %08x\n",
             regs[REG_PC], ifar, ifsr);
-      PANIC();
+      PANIC_WITH_REGS("panic", regs);
     }
 
   return regs;
@@ -131,7 +131,7 @@ uint32_t *arm_prefetchabort(uint32_t *regs, uint32_t ifar, uint32_t ifsr)
 
   _alert("Prefetch abort. PC: %08x IFAR: %08x IFSR: %08x\n",
         regs[REG_PC], ifar, ifsr);
-  PANIC();
+  PANIC_WITH_REGS("panic", regs);
   return regs; /* To keep the compiler happy */
 }
 
