@@ -39,6 +39,7 @@
 #include "addrenv.h"
 #include "arm.h"
 #include "arm_internal.h"
+#include "sched/sched.h"
 #include "signal/signal.h"
 
 /****************************************************************************
@@ -250,25 +251,6 @@ uint32_t *arm_syscall(uint32_t *regs)
         }
         break;
 #endif
-      /* R0=SYS_save_context:  This is a save context command:
-       *
-       *   int up_saveusercontext(void *saveregs);
-       *
-       * At this point, the following values are saved in context:
-       *
-       *   R0 = SYS_save_context
-       *   R1 = saveregs
-       *
-       * In this case, we simply need to copy the current registers to the
-       * save register space references in the saved R1 and return.
-       */
-
-      case SYS_save_context:
-        {
-          DEBUGASSERT(regs[REG_R1] != 0);
-          memcpy((uint32_t *)regs[REG_R1], regs, XCPTCONTEXT_SIZE);
-        }
-        break;
 
       /* R0=SYS_restore_context:  Restore task context
        *
@@ -604,6 +586,12 @@ uint32_t *arm_syscall(uint32_t *regs)
 
   if (regs != CURRENT_REGS)
     {
+      /* Record the new "running" task.  g_running_tasks[] is only used by
+       * assertion logic for reporting crashes.
+       */
+
+      g_running_tasks[this_cpu()] = this_task();
+
       restore_critical_section();
       regs = (uint32_t *)CURRENT_REGS;
     }
