@@ -32,7 +32,7 @@
  * Private Data
  ****************************************************************************/
 
-static uint32_t g_cpu_freq;
+static unsigned long g_cpu_freq;
 
 /****************************************************************************
  * Public Functions
@@ -60,26 +60,26 @@ static uint32_t g_cpu_freq;
 
 void up_perf_init(void *arg)
 {
-  g_cpu_freq = (uint32_t)(uintptr_t)arg;
+  g_cpu_freq = (unsigned long)(uintptr_t)arg;
 
   cp15_pmu_uer(PMUER_UME);
   cp15_pmu_pmcr(PMCR_E);
   cp15_pmu_cesr(PMCESR_CCES);
 }
 
-uint32_t up_perf_getfreq(void)
+unsigned long up_perf_getfreq(void)
 {
   return g_cpu_freq;
 }
 
-uint32_t up_perf_gettime(void)
+unsigned long up_perf_gettime(void)
 {
   return cp15_pmu_rdccr();
 }
 
-void up_perf_convert(uint32_t elapsed, struct timespec *ts)
+void up_perf_convert(unsigned long elapsed, struct timespec *ts)
 {
-  uint32_t left;
+  unsigned long left;
 
   ts->tv_sec  = elapsed / g_cpu_freq;
   left        = elapsed - ts->tv_sec * g_cpu_freq;
