@@ -400,6 +400,12 @@ static void _dmac_intc_handler(int ch)
   int itc;
   int err;
 
+  if (dev == NULL)
+    {
+      dmaerr("Cannot get device with channel number %d.\n", ch);
+      return;
+    }
+
   mask = (1u << (ch & 1));
 
   if (is_dmac(2, dev))
@@ -442,9 +448,16 @@ static int intr_handler_admac1(int irq, void *context, void *arg)
 static int intr_handler_idmac(int irq, void *context, void *arg)
 {
   struct dmac_register_map *dev = get_device(2); /* XXX */
-  uint32_t stat = dev->intstatus & 0x1f;
+  uint32_t stat;
   int i;
 
+  if (dev == NULL)
+    {
+      return -ENODEV;
+    }
+
+  stat = dev->intstatus & 0x1f;
+
   for (i = 2; stat; i++, stat >>= 1)
     {
       if (stat & 1)
