@@ -60,7 +60,17 @@
 #define NRF53_TWIM1_BASE        0x50009000
 #define NRF53_TWIS1_BASE        0x50009000
 #define NRF53_UART1_BASE        0x50009000
-#define NRF53_SPIM2_BASE        0x5000A000
+#define NRF53_SPIM4_BASE        0x5000A000
+#define NRF53_SPIM2_BASE        0x5000B000
+#define NRF53_SPIS2_BASE        0x5000B000
+#define NRF53_TWIM2_BASE        0x5000B000
+#define NRF53_TWIS2_BASE        0x5000B000
+#define NRF53_UART2_BASE        0x5000B000
+#define NRF53_SPIM3_BASE        0x5000C000
+#define NRF53_SPIS3_BASE        0x5000C000
+#define NRF53_TWIM3_BASE        0x5000C000
+#define NRF53_TWIS3_BASE        0x5000C000
+#define NRF53_UART3_BASE        0x5000C000
 #define NRF53_GPIOTE0_BASE      0x5000D000
 #define NRF53_SAADC_BASE        0x5000E000
 #define NRF53_TIMER0_BASE       0x5000F000
@@ -91,7 +101,7 @@
 #define NRF53_MUTEX_BASE        0x50030000
 #define NRF53_QDEC_BASE         0x50033000
 #define NRF53_USBD_BASE         0x50036000
-#define NRF53_USBREGULATOR_BASE 0x50037000
+#define NRF53_USBREG_BASE       0x50037000
 #define NRF53_KMU_BASE          0x50039000
 #define NRF53_NVMC_BASE         0x50039000
 #define NRF53_GPIO_P0_BASE      0x50842500
