@@ -36,6 +36,7 @@
 #include "nvic.h"
 
 #include "nrf53_clockconfig.h"
+#include "hardware/nrf53_nvmc.h"
 #include "hardware/nrf53_utils.h"
 #include "hardware/nrf53_uicr.h"
 #include "hardware/nrf53_ctrlap.h"
@@ -100,6 +101,61 @@ void nrf53_approtect(void)
 #endif
 }
 
+#ifdef CONFIG_NRF53_FLASH_PREFETCH
+
+/****************************************************************************
+ * Name: nrf53_enable_icache
+ *
+ * Description:
+ *   Enable I-Cache for Flash
+ *
+ * Input Parameter:
+ *   enable - enable or disable I-Cache
+ *
+ * Returned Values:
+ *   None
+ *
+ ****************************************************************************/
+
+void nrf53_enable_icache(bool enable)
+{
+  if (enable)
+    {
+      modifyreg32(NRF53_NVMC_ICACHECNF, 0, NVMC_ICACHECNF_CACHEEN);
+    }
+  else
+    {
+      modifyreg32(NRF53_NVMC_ICACHECNF, NVMC_ICACHECNF_CACHEEN, 0);
+    }
+}
+
+/****************************************************************************
+ * Name: nrf53_enable_profile
+ *
+ * Description:
+ *   Enable profiling I-Cache for flash
+ *
+ * Input Parameter:
+ *   enable - enable or disable profiling for I-Cache
+ *
+ * Returned Values:
+ *   None
+ *
+ ****************************************************************************/
+
+void nrf53_enable_profile(bool enable)
+{
+  if (enable)
+    {
+      modifyreg32(NRF53_NVMC_ICACHECNF, 0, NVMC_ICACHECNF_CACHEPROFEN);
+    }
+  else
+    {
+      modifyreg32(NRF53_NVMC_ICACHECNF, NVMC_ICACHECNF_CACHEPROFEN, 0);
+    }
+}
+#endif
+
 /****************************************************************************
  * Public Functions
  ****************************************************************************/
@@ -179,6 +235,11 @@ void __start(void)
   arm_fpuconfig();
 #endif
 
+#ifdef CONFIG_NRF53_FLASH_PREFETCH
+  nrf53_enable_icache(true);
+  nrf53_enable_profile(true);
+#endif
+
   showprogress('D');
 
 #ifdef USE_EARLYSERIALINIT
