@@ -437,8 +437,8 @@ static int nand_rawwrite(struct nand_raw_s *raw, off_t block,
   int ret = OK;
 
   DEBUGASSERT(raw);
-  finfo("block=%d page=%d data=%p spare=%p\n",
-        (int)block, page, data, spare);
+  finfo("block=%" PRIdOFF " page=%d data=%p spare=%p\n",
+        block, page, data, spare);
 
   /* Get page and spare sizes */
 
