@@ -140,7 +140,7 @@
                                             /* 0x0004b000-0x0004bfff: Reserved */
 #  define SAM_SFC_OFFSET         0x0004c000 /* 0x0004c000-0x0004ffff: SFC */
 #  define SAM_I2SC0_OFFSET       0x00050000 /* 0x00050000-0x00053fff: I2SC0 */
-#  define SAM_CAN0_OFFSET        0x00054000 /* 0x00054000-0x00057fff: CAN0 */
+#  define SAM_MCAN0_OFFSET       0x00054000 /* 0x00054000-0x00057fff: MCAN0 */
 #  define SAM_SYSC_PSECTION      0xf8048000 /* 0xf8048000-0xf8048fff: System Controller */
 #  define SAM_SYSC_PADDR         0xf8048000 /* 0xf8048000-0xf8048fff: System Controller */
 
@@ -165,7 +165,7 @@
 #  define SAM_TDES_OFFSET        0x00044000 /* 0x00044000-0x00047fff: TDES */
 #  define SAM_CLASSD_OFFSET      0x00048000 /* 0x00048000-0x0004bfff: Class D */
 #  define SAM_I2SC1_OFFSET       0x0004c000 /* 0x0004c000-0x0004ffff: I2SC1 */
-#  define SAM_CAN1_OFFSET        0x00050000 /* 0x00050000-0x00053fff: CAN1 */
+#  define SAM_MCAN1_OFFSET       0x00050000 /* 0x00050000-0x00053fff: MCAN1 */
 #  define SAM_UTMI_OFFSET        0x00054000 /* 0x00054000-0x00057fff: UTMI */
                                             /* 0x00058000-0x0005bfff: Reserved */
 #  define SAM_SFRBU_OFFSET       0x0005c000 /* 0x0005c000-0x0005ffff: SFRBU */
@@ -492,7 +492,7 @@
 #define SAM_ACC_VBASE            (SAM_PERIPHB_VSECTION+SAM_ACC_OFFSET)
 #define SAM_SFC_VBASE            (SAM_PERIPHB_VSECTION+SAM_SFC_OFFSET)
 #define SAM_I2SC0_VBASE          (SAM_PERIPHB_VSECTION+SAM_I2SC0_OFFSET)
-#define SAM_CAN0_VBASE           (SAM_PERIPHB_VSECTION+SAM_CAN0_OFFSET)
+#define SAM_MCAN0_VBASE          (SAM_PERIPHB_VSECTION+SAM_MCAN0_OFFSET)
 
 #define SAM_SPI1_VBASE           (SAM_PERIPHC_VSECTION+SAM_SPI1_OFFSET)
 #define SAM_SSC1_VBASE           (SAM_PERIPHC_VSECTION+SAM_SSC1_OFFSET)
@@ -512,7 +512,7 @@
 #define SAM_TDES_VBASE           (SAM_PERIPHC_VSECTION+SAM_TDES_OFFSET)
 #define SAM_CLASSD_VBASE         (SAM_PERIPHC_VSECTION+SAM_CLASSD_OFFSET)
 #define SAM_I2SC1_VBASE          (SAM_PERIPHC_VSECTION+SAM_I2SC1_OFFSET)
-#define SAM_CAN1_VBASE           (SAM_PERIPHC_VSECTION+SAM_CAN1_OFFSET)
+#define SAM_MCAN1_VBASE          (SAM_PERIPHC_VSECTION+SAM_MCAN1_OFFSET)
 #define SAM_UTMI_VBASE           (SAM_PERIPHC_VSECTION+SAM_UTMI_OFFSET)
 #define SAM_SFRBU_VBASE          (SAM_PERIPHC_VSECTION+SAM_SFRBU_OFFSET)
 #define SAM_CHIPID_VBASE         (SAM_PERIPHC_VSECTION+SAM_CHIPID_OFFSET)
@@ -522,6 +522,10 @@
 #define SAM_PIOC_VBASE           SAM_PIO_IOGROUPC_VBASE
 #define SAM_PIOD_VBASE           SAM_PIO_IOGROUPD_VBASE
 
+#define SAM_FLEXCOM_USART_OFFSET (0x200)
+#define SAM_FLEXCOM_SPI_OFFSET   (0x400)
+#define SAM_FLEXCOM_TWI_OFFSET   (0x600)
+
 /* NuttX virtual base address
  *
  * The boot logic will create a temporarily mapping based on where NuttX is
