@@ -209,7 +209,7 @@ static void flexus_shutdown(struct uart_dev_s *dev);
 static int  flexus_attach(struct uart_dev_s *dev);
 static void flexus_detach(struct uart_dev_s *dev);
 static int  flexus_ioctl(struct file *filep, int cmd, unsigned long arg);
-static int  flexus_receive(struct uart_dev_s *dev, uint32_t *status);
+static int  flexus_receive(struct uart_dev_s *dev, unsigned int *status);
 static void flexus_rxint(struct uart_dev_s *dev, bool enable);
 static bool flexus_rxavailable(struct uart_dev_s *dev);
 static void flexus_send(struct uart_dev_s *dev, int ch);
@@ -494,9 +494,11 @@ static void flexus_disableallints(struct flexus_dev_s *priv, uint32_t *imr)
  * Name: flexus_interrupt
  *
  * Description:
- *   This is the common USART interrupt handler.  It should call
- *   uart_transmitchars or uart_receivechar to perform the appropriate
- *   data transfers.
+ *   This is the common USART interrupt handler.  It will be invoked when an
+ *   interrupt is received on the 'irq'.  It should call uart_xmitchars or
+ *   uart_recvchars to perform the appropriate data transfers.  The
+ *   interrupt handling logic must be able to map the 'arg' to the
+ *   appropriate uart_dev_s structure in order to call these functions.
  *
  ****************************************************************************/
 
@@ -961,7 +963,7 @@ static int flexus_ioctl(struct file *filep, int cmd, unsigned long arg)
  *
  ****************************************************************************/
 
-static int flexus_receive(struct uart_dev_s *dev, uint32_t *status)
+static int flexus_receive(struct uart_dev_s *dev, unsigned int *status)
 {
   struct flexus_dev_s *priv = (struct flexus_dev_s *)dev->priv;
 
