@@ -31,6 +31,7 @@
 #include <inttypes.h>
 #include <stdint.h>
 #include <string.h>
+#include <sys/param.h>
 #include <assert.h>
 #include <errno.h>
 #include <debug.h>
@@ -573,10 +574,6 @@
 #  endif
 #endif
 
-/* Helper */
-
-#define MIN(x,y)                    ((x) < (y) ? (x) : (y))
-
 /* Color normalization */
 
 #if defined(CONFIG_STM32_LTDC_L1_RGB565)
