@@ -91,6 +91,25 @@
 #define STACK_COLOR    0xdeaddead
 #define HEAP_COLOR     'h'
 
+/* AArch64 the stack-pointer must be 128-bit aligned */
+
+#define STACK_ALIGNMENT     16
+
+/* Stack alignment macros */
+
+#define STACK_ALIGN_MASK    (STACK_ALIGNMENT - 1)
+#define STACK_ALIGN_DOWN(a) ((a) & ~STACK_ALIGN_MASK)
+#define STACK_ALIGN_UP(a)   (((a) + STACK_ALIGN_MASK) & ~STACK_ALIGN_MASK)
+
+#ifdef CONFIG_SMP
+/* The size of interrupt and idle stack.  This is the configured
+ * value aligned the 8-bytes as required by the ARM EABI.
+ */
+
+#  define SMP_STACK_SIZE    STACK_ALIGN_UP(CONFIG_IDLETHREAD_STACKSIZE)
+#  define SMP_STACK_WORDS   (SMP_STACK_SIZE >> 2)
+#endif
+
 /****************************************************************************
  * Public Types
  ****************************************************************************/
@@ -112,16 +131,6 @@ extern "C"
 #define EXTERN extern
 #endif
 
-/* AArch64 the stack-pointer must be 128-bit aligned */
-
-#define STACK_ALIGNMENT     16
-
-/* Stack alignment macros */
-
-#define STACK_ALIGN_MASK    (STACK_ALIGNMENT - 1)
-#define STACK_ALIGN_DOWN(a) ((a) & ~STACK_ALIGN_MASK)
-#define STACK_ALIGN_UP(a)   (((a) + STACK_ALIGN_MASK) & ~STACK_ALIGN_MASK)
-
 #define INIT_STACK_DEFINE(sym, size) \
     char locate_data(".initstack") \
      aligned_data(STACK_ALIGNMENT) sym[size]
@@ -143,12 +152,6 @@ extern "C"
 
 #ifdef CONFIG_SMP
 
-/* The size of interrupt and idle stack.  This is the configured
- * value aligned the 8-bytes as required by the ARM EABI.
- */
-
-#define SMP_STACK_SIZE       STACK_ALIGN_UP(CONFIG_IDLETHREAD_STACKSIZE)
-
 INIT_STACK_ARRAY_DEFINE_EXTERN(g_cpu_idlestackalloc, CONFIG_SMP_NCPUS,
                           SMP_STACK_SIZE);
 INIT_STACK_ARRAY_DEFINE_EXTERN(g_interrupt_stacks, CONFIG_SMP_NCPUS,
@@ -254,7 +257,6 @@ void arm64_secondary_start(void);
 
 void arm64_fullcontextrestore(uint64_t *restoreregs) noreturn_function;
 void arm64_switchcontext(uint64_t **saveregs, uint64_t *restoreregs);
-void arm64_context_snapshot(void *savereg);
 
 /* Signal handling **********************************************************/
 
@@ -283,7 +285,7 @@ uint64_t *arm64_doirq(int irq, uint64_t *regs);
 #ifdef CONFIG_PAGING
 void arm64_pginitialize(void);
 #else /* CONFIG_PAGING */
-# define arm64_pginitialize()
+#  define arm64_pginitialize()
 #endif /* CONFIG_PAGING */
 
 uint64_t * arm64_syscall_switch(uint64_t *regs);
@@ -322,8 +324,6 @@ void arm64_serialinit(void);
 void arm64_earlyserialinit(void);
 #endif
 
-void arm64_lowputc(char c);
-
 /* DMA */
 
 #ifdef CONFIG_ARCH_DMA
@@ -335,7 +335,7 @@ void weak_function arm64_dma_initialize(void);
 #if CONFIG_MM_REGIONS > 1
 void arm64_addregion(void);
 #else
-# define arm64_addregion()
+#  define arm64_addregion()
 #endif
 
 /* Networking */
@@ -354,7 +354,7 @@ void arm64_addregion(void);
 #if defined(CONFIG_NET) && !defined(CONFIG_NETDEV_LATEINIT)
 void arm64_netinitialize(void);
 #else
-# define arm64_netinitialize()
+#  define arm64_netinitialize()
 #endif
 
 /* USB */
@@ -363,8 +363,8 @@ void arm64_netinitialize(void);
 void arm64_usbinitialize(void);
 void arm64_usbuninitialize(void);
 #else
-# define arm64_usbinitialize()
-# define arm64_usbuninitialize()
+#  define arm64_usbinitialize()
+#  define arm64_usbuninitialize()
 #endif
 
 /* Debug */
