@@ -31,8 +31,6 @@
 #include <stdint.h>
 #include <stdbool.h>
 #include <arch/chip/chip.h>
-#include "arm64_internal.h"
-#include "arm64_arch.h"
 
 /****************************************************************************
  * Pre-processor Definitions
