@@ -27,13 +27,13 @@
 #include <stdint.h>
 #include <assert.h>
 
+#include <nuttx/addrenv.h>
 #include <nuttx/irq.h>
 #include <nuttx/arch.h>
 #include <nuttx/board.h>
 #include <arch/board/board.h>
 
 #include "hc_internal.h"
-#include "group/group.h"
 
 /****************************************************************************
  * Pre-processor Definitions
@@ -97,7 +97,7 @@ uint8_t *hc_doirq(int irq, uint8_t *regs)
        * thread at the head of the ready-to-run list.
        */
 
-      group_addrenv(NULL);
+      addrenv_switch(NULL);
 #endif
     }
 #endif
