@@ -173,17 +173,17 @@ struct rx65n_rspidev_s
 
 /* Helpers */
 
-static inline uint32_t rspi_getreg32(FAR struct rx65n_rspidev_s *priv,
+static inline uint32_t rspi_getreg32(struct rx65n_rspidev_s *priv,
                                      uint8_t offset);
-static inline uint16_t rspi_getreg16(FAR struct rx65n_rspidev_s *priv,
+static inline uint16_t rspi_getreg16(struct rx65n_rspidev_s *priv,
                                      uint8_t offset);
-static inline uint8_t rspi_getreg8(FAR struct rx65n_rspidev_s *priv,
+static inline uint8_t rspi_getreg8(struct rx65n_rspidev_s *priv,
                                    uint8_t offset);
-static inline void rspi_putreg32(FAR struct rx65n_rspidev_s *priv,
+static inline void rspi_putreg32(struct rx65n_rspidev_s *priv,
                                  uint8_t offset, uint32_t value);
-static inline void rspi_putreg16(FAR struct rx65n_rspidev_s *priv,
+static inline void rspi_putreg16(struct rx65n_rspidev_s *priv,
                                  uint8_t offset, uint16_t value);
-static inline void rspi_putreg8(FAR struct rx65n_rspidev_s *priv,
+static inline void rspi_putreg8(struct rx65n_rspidev_s *priv,
                                 uint8_t offset, uint8_t value);
 
 /* SPI data transfer */
@@ -199,47 +199,45 @@ static void rspi_rxuint8(struct rx65n_rspidev_s *priv);
 static void rspi_performtx(struct rx65n_rspidev_s *priv);
 static inline void rspi_performrx(struct rx65n_rspidev_s *priv);
 static int rspi_transfer(struct rx65n_rspidev_s *priv, const void *txbuffer,
-                           void *rxbuffer, unsigned int nwords);
+                         void *rxbuffer, unsigned int nwords);
 
 /* Interrupt handling */
 
 #ifndef CONFIG_SPI_POLLWAIT
 static inline struct rx65n_rspidev_s *rspi_mapirq(int irq);
-static int rspi_idlinterrupt(int irq, void *context, FAR void *arg);
-static int rspi_erinterrupt(int irq, void *context, FAR void *arg);
-static int rspi_txinterrupt(int irq, void *context, FAR void *arg);
-static int rspi_rxinterrupt(int irq, void *context, FAR void *arg);
+static int rspi_idlinterrupt(int irq, void *context, void *arg);
+static int rspi_erinterrupt(int irq, void *context, void *arg);
+static int rspi_txinterrupt(int irq, void *context, void *arg);
+static int rspi_rxinterrupt(int irq, void *context, void *arg);
 #endif
 
 /* SPI methods */
 
-static int   rspi_lock(FAR struct spi_dev_s *dev, bool lock);
-static uint32_t rspi_setfrequency(FAR struct spi_dev_s *dev,
+static int   rspi_lock(struct spi_dev_s *dev, bool lock);
+static uint32_t rspi_setfrequency(struct spi_dev_s *dev,
                                   uint32_t frequency);
-static void  rspi_setmode(FAR struct spi_dev_s *dev, enum spi_mode_e mode);
-static void  rspi_setbits(FAR struct spi_dev_s *dev, int nbits);
+static void  rspi_setmode(struct spi_dev_s *dev, enum spi_mode_e mode);
+static void  rspi_setbits(struct spi_dev_s *dev, int nbits);
 #ifdef CONFIG_SPI_HWFEATURES
-static int  rspi_hwfeatures(FAR struct spi_dev_s *dev,
-                                  spi_hwfeatures_t features);
+static int  rspi_hwfeatures(struct spi_dev_s *dev,
+                            spi_hwfeatures_t features);
 #endif
-static uint32_t rspi_send(FAR struct spi_dev_s *dev, uint32_t wd);
-static void rspi_exchange(FAR struct spi_dev_s *dev,
-                               FAR const void *txbuffer,
-                                FAR void *rxbuffer, size_t nwords);
+static uint32_t rspi_send(struct spi_dev_s *dev, uint32_t wd);
+static void rspi_exchange(struct spi_dev_s *dev, const void *txbuffer,
+                          void *rxbuffer, size_t nwords);
 #ifdef CONFIG_SPI_TRIGGER
-static int  rspi_trigger(FAR struct spi_dev_s *dev);
+static int  rspi_trigger(struct spi_dev_s *dev);
 #endif
 #ifndef CONFIG_SPI_EXCHANGE
-static void rspi_sndblock(FAR struct spi_dev_s *dev,
-                            FAR const void *txbuffer,
-                                size_t nwords);
-static void  rspi_recvblock(FAR struct spi_dev_s *dev, FAR void *rxbuffer,
-                                 size_t nwords);
+static void rspi_sndblock(struct spi_dev_s *dev, const void *txbuffer,
+                          size_t nwords);
+static void  rspi_recvblock(struct spi_dev_s *dev, void *rxbuffer,
+                            size_t nwords);
 #endif
 
 /* Initialization */
 
-static void  rspi_bus_initialize(FAR struct rx65n_rspidev_s *priv);
+static void  rspi_bus_initialize(struct rx65n_rspidev_s *priv);
 
 /****************************************************************************
  * Private Data
@@ -439,57 +437,57 @@ static struct rx65n_rspidev_s g_rspi2dev =
  *
  ****************************************************************************/
 #ifdef CONFIG_RX65N_RSPI0
-void rx65n_rspi0select(FAR struct spi_dev_s *dev, uint32_t devid,
+void rx65n_rspi0select(struct spi_dev_s *dev, uint32_t devid,
                        bool selected)
 {
   spiinfo("devid: %d CS: %s\n", (int)devid, selected ? "assert" :
                                                    "de-assert");
 }
 
-uint8_t rx65n_rspi0status(FAR struct spi_dev_s *dev, uint32_t devid)
+uint8_t rx65n_rspi0status(struct spi_dev_s *dev, uint32_t devid)
 {
   return 0;
 }
 
-int rx65n_rspi0cmddata(FAR struct spi_dev_s *dev, uint32_t devid, bool cmd)
+int rx65n_rspi0cmddata(struct spi_dev_s *dev, uint32_t devid, bool cmd)
 {
   return -ENODEV;
 }
 #endif
 
 #ifdef CONFIG_RX65N_RSPI1
-void rx65n_rspi1select(FAR struct spi_dev_s *dev, uint32_t devid,
+void rx65n_rspi1select(struct spi_dev_s *dev, uint32_t devid,
                        bool selected)
 {
   spiinfo("devid: %d CS: %s\n", (int)devid, selected ? "assert" :
                                                          "de-assert");
 }
 
-uint8_t rx65n_rspi1status(FAR struct spi_dev_s *dev, uint32_t devid)
+uint8_t rx65n_rspi1status(struct spi_dev_s *dev, uint32_t devid)
 {
   return 0;
 }
 
-int rx65n_rspi1cmddata(FAR struct spi_dev_s *dev, uint32_t devid, bool cmd)
+int rx65n_rspi1cmddata(struct spi_dev_s *dev, uint32_t devid, bool cmd)
 {
   return -ENODEV;
 }
 #endif
 
 #ifdef CONFIG_RX65N_RSPI2
-void rx65n_rspi2select(FAR struct spi_dev_s *dev, uint32_t devid,
+void rx65n_rspi2select(struct spi_dev_s *dev, uint32_t devid,
                        bool selected)
 {
   spiinfo("devid: %d CS: %s\n", (int)devid, selected ? "assert" :
                                                           "de-assert");
 }
 
-uint8_t rx65n_rspi2status(FAR struct spi_dev_s *dev, uint32_t devid)
+uint8_t rx65n_rspi2status(struct spi_dev_s *dev, uint32_t devid)
 {
   return 0;
 }
 
-int rx65n_rspi2cmddata(FAR struct spi_dev_s *dev, uint32_t devid, bool cmd)
+int rx65n_rspi2cmddata(struct spi_dev_s *dev, uint32_t devid, bool cmd)
 {
   return -ENODEV;
 }
@@ -516,9 +514,8 @@ int rx65n_rspi2cmddata(FAR struct spi_dev_s *dev, uint32_t devid, bool cmd)
  ****************************************************************************/
 #ifdef CONFIG_SPI_CALLBACK
 #ifdef CONFIG_RX65N_RSPI0
-int rx65n_rspi0register(FAR struct spi_dev_s *dev,
-                        spi_mediachange_t callback,
-                       FAR void *arg)
+int rx65n_rspi0register(struct spi_dev_s *dev, spi_mediachange_t callback,
+                        void *arg)
 {
   spiinfo("INFO: Registering rspi0 device\n");
   return OK;
@@ -526,9 +523,8 @@ int rx65n_rspi0register(FAR struct spi_dev_s *dev,
 #endif
 
 #ifdef CONFIG_RX65N_RSPI1
-int rx65n_rspi1register(FAR struct spi_dev_s *dev,
-                        spi_mediachange_t callback,
-                       FAR void *arg)
+int rx65n_rspi1register(struct spi_dev_s *dev, spi_mediachange_t callback,
+                        void *arg)
 {
   spiinfo("INFO: Registering rspi1 device\n");
   return OK;
@@ -536,9 +532,8 @@ int rx65n_rspi1register(FAR struct spi_dev_s *dev,
 #endif
 
 #ifdef CONFIG_RX65N_RSPI2
-int rx65n_rspi2register(FAR struct spi_dev_s *dev,
-                         spi_mediachange_t callback,
-                       FAR void *arg)
+int rx65n_rspi2register(struct spi_dev_s *dev, spi_mediachange_t callback,
+                        void *arg)
 {
   spiinfo("INFO: Registering rspi2 device\n");
   return OK;
@@ -630,7 +625,7 @@ static inline uint8_t rspi_getreg8(struct rx65n_rspidev_s *priv,
  ****************************************************************************/
 
 static inline void rspi_putreg32(struct rx65n_rspidev_s *priv,
-                              uint8_t offset, uint32_t value)
+                                 uint8_t offset, uint32_t value)
 {
   putreg32(value, priv->rspibase + offset);
 }
@@ -652,7 +647,7 @@ static inline void rspi_putreg32(struct rx65n_rspidev_s *priv,
  ****************************************************************************/
 
 static inline void rspi_putreg16(struct rx65n_rspidev_s *priv,
-                              uint8_t offset, uint16_t value)
+                                 uint8_t offset, uint16_t value)
 {
   putreg16(value, priv->rspibase + offset);
 }
@@ -674,7 +669,7 @@ static inline void rspi_putreg16(struct rx65n_rspidev_s *priv,
  ****************************************************************************/
 
 static inline void rspi_putreg8(struct rx65n_rspidev_s *priv,
-                              uint8_t offset, uint8_t value)
+                                uint8_t offset, uint8_t value)
 {
   putreg8(value, priv->rspibase + offset);
 }
@@ -912,7 +907,7 @@ static void rspi_startxfr(struct rx65n_rspidev_s *priv)
  ****************************************************************************/
 
 static int rspi_transfer(struct rx65n_rspidev_s *priv, const void *txbuffer,
-                        void *rxbuffer, unsigned int nwords)
+                         void *rxbuffer, unsigned int nwords)
 {
   uint8_t regval8;
 #ifndef CONFIG_SPI_POLLWAIT
@@ -1178,7 +1173,7 @@ static void rspi_errhandle(struct rx65n_rspidev_s *priv, uint8_t bus)
  ****************************************************************************/
 
 #ifndef CONFIG_SPI_POLLWAIT
-static int rspi_idlinterrupt(int irq, void *context, FAR void *arg)
+static int rspi_idlinterrupt(int irq, void *context, void *arg)
 {
   uint8_t regval8;
 
@@ -1221,7 +1216,7 @@ static int rspi_idlinterrupt(int irq, void *context, FAR void *arg)
  ****************************************************************************/
 
 #ifndef CONFIG_SPI_POLLWAIT
-static int rspi_erinterrupt(int irq, void *context, FAR void *arg)
+static int rspi_erinterrupt(int irq, void *context, void *arg)
 {
   struct rx65n_rspidev_s *priv = rspi_mapirq(irq);
 
@@ -1264,7 +1259,7 @@ static int rspi_erinterrupt(int irq, void *context, FAR void *arg)
  ****************************************************************************/
 
 #ifndef CONFIG_SPI_POLLWAIT
-static int rspi_rxinterrupt(int irq, void *context, FAR void *arg)
+static int rspi_rxinterrupt(int irq, void *context, void *arg)
 {
   struct rx65n_rspidev_s *priv = rspi_mapirq(irq);
 
@@ -1299,7 +1294,7 @@ static int rspi_rxinterrupt(int irq, void *context, FAR void *arg)
  ****************************************************************************/
 
 #ifndef CONFIG_SPI_POLLWAIT
-static int rspi_txinterrupt(int irq, void *context, FAR void *arg)
+static int rspi_txinterrupt(int irq, void *context, void *arg)
 {
   struct rx65n_rspidev_s *priv = rspi_mapirq(irq);
 
@@ -1334,7 +1329,7 @@ static int rspi_txinterrupt(int irq, void *context, FAR void *arg)
  *
  ****************************************************************************/
 
-static int rspi_lock(FAR struct spi_dev_s *dev, bool lock)
+static int rspi_lock(struct spi_dev_s *dev, bool lock)
 {
   struct rx65n_rspidev_s *priv = (struct rx65n_rspidev_s *)dev;
   int ret;
@@ -1366,8 +1361,8 @@ static int rspi_lock(FAR struct spi_dev_s *dev, bool lock)
  *
  ****************************************************************************/
 
-static uint32_t rspi_setfrequency(FAR struct spi_dev_s *dev,
-                                 uint32_t frequency)
+static uint32_t rspi_setfrequency(struct spi_dev_s *dev,
+                                  uint32_t frequency)
 {
   struct rx65n_rspidev_s *priv = (struct rx65n_rspidev_s *)dev;
   uint32_t actual;
@@ -1466,7 +1461,7 @@ static uint32_t rspi_setfrequency(FAR struct spi_dev_s *dev,
  *
  ****************************************************************************/
 
-static void rspi_setmode(FAR struct spi_dev_s *dev, enum spi_mode_e mode)
+static void rspi_setmode(struct spi_dev_s *dev, enum spi_mode_e mode)
 {
   struct rx65n_rspidev_s *priv = (struct rx65n_rspidev_s *)dev;
 
@@ -1529,7 +1524,7 @@ static void rspi_setmode(FAR struct spi_dev_s *dev, enum spi_mode_e mode)
  *
  ****************************************************************************/
 
-static void rspi_setbits(FAR struct spi_dev_s *dev, int nbits)
+static void rspi_setbits(struct spi_dev_s *dev, int nbits)
 {
   struct rx65n_rspidev_s *priv = (struct rx65n_rspidev_s *)dev;
 
@@ -1585,7 +1580,7 @@ static void rspi_setbits(FAR struct spi_dev_s *dev, int nbits)
  *
  ****************************************************************************/
 
-static uint32_t rspi_send(FAR struct spi_dev_s *dev, uint32_t wd)
+static uint32_t rspi_send(struct spi_dev_s *dev, uint32_t wd)
 {
   struct rx65n_rspidev_s *priv = (struct rx65n_rspidev_s *)dev;
   uint32_t response = 0;
@@ -1616,9 +1611,8 @@ static uint32_t rspi_send(FAR struct spi_dev_s *dev, uint32_t wd)
  ****************************************************************************/
 
 #ifdef CONFIG_SPI_EXCHANGE
-static void rspi_exchange(FAR struct spi_dev_s *dev,
-                            FAR const void *txbuffer,
-                         FAR void *rxbuffer, size_t nwords)
+static void rspi_exchange(struct spi_dev_s *dev, const void *txbuffer,
+                          void *rxbuffer, size_t nwords)
 {
   struct rx65n_rspidev_s *priv = (struct rx65n_rspidev_s *)dev;
   rspi_transfer(priv, txbuffer, rxbuffer, nwords);
@@ -1646,8 +1640,8 @@ static void rspi_exchange(FAR struct spi_dev_s *dev,
  ****************************************************************************/
 
 #ifndef CONFIG_SPI_EXCHANGE
-static void rspi_sndblock(FAR struct spi_dev_s *dev, FAR const void *buffer,
-                         size_t nwords)
+static void rspi_sndblock(struct spi_dev_s *dev, const void *buffer,
+                          size_t nwords)
 {
   struct rx65n_rspidev_s *priv = (struct rx65n_rspidev_s *)dev;
   rspi_transfer(priv, buffer, NULL, nwords);
@@ -1675,8 +1669,8 @@ static void rspi_sndblock(FAR struct spi_dev_s *dev, FAR const void *buffer,
  ****************************************************************************/
 
 #ifndef CONFIG_SPI_EXCHANGE
-static void rspi_recvblock(FAR struct spi_dev_s *dev, FAR void *buffer,
-                          size_t nwords)
+static void rspi_recvblock(struct spi_dev_s *dev, void *buffer,
+                           size_t nwords)
 {
   struct rx65n_rspidev_s *priv = (struct rx65n_rspidev_s *)dev;
   rspi_transfer(priv, NULL, buffer, nwords);
@@ -1690,7 +1684,7 @@ static void rspi_recvblock(FAR struct spi_dev_s *dev, FAR void *buffer,
  * Return Value : none
  ****************************************************************************/
 
-void rspi_interrupt_init(FAR struct rx65n_rspidev_s *priv, uint8_t bus)
+void rspi_interrupt_init(struct rx65n_rspidev_s *priv, uint8_t bus)
 {
   /* Enable error interrupt source bit */
 
@@ -1844,7 +1838,7 @@ static void rspi_reg_protect(uint8_t enable)
  *
  ****************************************************************************/
 
-static void rspi_bus_initialize(FAR struct rx65n_rspidev_s *priv)
+static void rspi_bus_initialize(struct rx65n_rspidev_s *priv)
 {
   uint8_t regval8;
   uint16_t regval16;
@@ -1882,7 +1876,7 @@ static void rspi_bus_initialize(FAR struct rx65n_rspidev_s *priv)
 
   /* Select a default frequency of approx. 400KHz */
 
-  rspi_setfrequency((FAR struct spi_dev_s *)priv, 400000);
+  rspi_setfrequency((struct spi_dev_s *)priv, 400000);
 
   /* Configure data control register SPDCR
    * Four frames can be transmitted or received in one round of transmission
@@ -2028,9 +2022,9 @@ static void rspi_bus_initialize(FAR struct rx65n_rspidev_s *priv)
  *
  ****************************************************************************/
 
-FAR struct spi_dev_s *rx65n_rspibus_initialize(int bus)
+struct spi_dev_s *rx65n_rspibus_initialize(int bus)
 {
-  FAR struct rx65n_rspidev_s *priv = NULL;
+  struct rx65n_rspidev_s *priv = NULL;
 
   irqstate_t flags = enter_critical_section();
 
@@ -2139,7 +2133,7 @@ FAR struct spi_dev_s *rx65n_rspibus_initialize(int bus)
     }
 
   leave_critical_section(flags);
-  return (FAR struct spi_dev_s *)priv;
+  return (struct spi_dev_s *)priv;
 }
 
 #endif /* CONFIG_RX65N_RSPI0 || CONFIG_RX65N_RSPI1 || CONFIG_RX65N_RSPI2 */
