@@ -281,10 +281,10 @@ static void up_shutdown(struct uart_dev_s *dev);
 static int  up_attach(struct uart_dev_s *dev);
 static void up_detach(struct uart_dev_s *dev);
 static int  up_ioctl(struct file *filep, int cmd, unsigned long arg);
-static int  up_xmtinterrupt(int irq, void *context, FAR void *arg);
-static int  up_rcvinterrupt(int irq, void *context, FAR void *arg);
-static int  up_eriinterrupt(int irq, void *context, FAR void *arg);
-static int  up_teiinterrupt(int irq, void *context, FAR void *arg);
+static int  up_xmtinterrupt(int irq, void *context, void *arg);
+static int  up_rcvinterrupt(int irq, void *context, void *arg);
+static int  up_eriinterrupt(int irq, void *context, void *arg);
+static int  up_teiinterrupt(int irq, void *context, void *arg);
 static int  up_receive(struct uart_dev_s *dev, unsigned int *status);
 static void up_rxint(struct uart_dev_s *dev, bool enable);
 static bool up_rxavailable(struct uart_dev_s *dev);
@@ -1259,16 +1259,15 @@ static int up_rcvinterrupt(int irq, void *context, void *arg)
  * Name: up_xmtinterrupt
  *
  * Description:
- *   This is the SCI interrupt handler.  It will be invoked
- *   when an interrupt received on the 'irq'  It should call
- *   uart_transmitchars or uart_receivechar to perform the
- *   appropriate data transfers.  The interrupt handling logic\
- *   must be able to map the 'irq' number into the appropriate
- *   up_dev_s structure in order to call these functions.
+ *   This is the SCI interrupt handler.  It will be invoked when an
+ *   interrupt is received on the 'irq'.  It should call uart_xmitchars or
+ *   uart_recvchars to perform the appropriate data transfers.  The
+ *   interrupt handling logic must be able to map the 'arg' to the
+ *   appropriate uart_dev_s structure in order to call these functions.
  *
  ****************************************************************************/
 
-static int  up_xmtinterrupt(int irq, void *context, FAR void *arg)
+static int  up_xmtinterrupt(int irq, void *context, void *arg)
 {
   struct uart_dev_s *dev;
   dev = (struct uart_dev_s *)arg;
