@@ -132,26 +132,6 @@ int riscv_swint(int irq, void *context, void *arg)
 
   switch (regs[REG_A0])
     {
-      /* A0=SYS_save_context:  This is a save context command:
-       *
-       *   int up_saveusercontext(void *saveregs);
-       *
-       * At this point, the following values are saved in context:
-       *
-       *   A0 = SYS_save_context
-       *   A1 = saveregs
-       *
-       * In this case, we simply need to copy the current registers to the
-       * save register space references in the saved A1 and return.
-       */
-
-      case SYS_save_context:
-        {
-          DEBUGASSERT(regs[REG_A1] != 0);
-          riscv_copystate((uintptr_t *)regs[REG_A1], regs);
-        }
-        break;
-
       /* A0=SYS_restore_context: This a restore context command:
        *
        * void
@@ -284,6 +264,14 @@ int riscv_swint(int irq, void *context, void *arg)
            * unprivileged mode.
            */
 
+#ifdef CONFIG_ARCH_KERNEL_STACK
+          /* Set the user stack pointer as we are about to return to user */
+
+          struct tcb_s *tcb  = nxsched_self();
+          regs[REG_SP]       = (uintptr_t)tcb->xcp.ustkptr;
+          tcb->xcp.ustkptr   = NULL;
+#endif
+
 #if defined (CONFIG_BUILD_PROTECTED)
           /* Use the nxtask_startup trampoline function */
 
@@ -322,6 +310,14 @@ int riscv_swint(int irq, void *context, void *arg)
            * unprivileged mode.
            */
 
+#ifdef CONFIG_ARCH_KERNEL_STACK
+          /* Set the user stack pointer as we are about to return to user */
+
+          struct tcb_s *tcb  = nxsched_self();
+          regs[REG_SP]       = (uintptr_t)tcb->xcp.ustkptr;
+          tcb->xcp.ustkptr   = NULL;
+#endif
+
           regs[REG_EPC]      = (uintptr_t)regs[REG_A1];  /* startup */
 
           /* Change the parameter ordering to match the expectation of the
@@ -391,18 +387,13 @@ int riscv_swint(int irq, void *context, void *arg)
             {
               uintptr_t usp;
 
-              DEBUGASSERT(rtcb->xcp.kstkptr == NULL);
+              /* Store the current kernel stack pointer so it is not lost */
+
+              rtcb->xcp.kstkptr = (uintptr_t *)regs[REG_SP];
 
               /* Copy "info" into user stack */
 
-              if (rtcb->xcp.sigdeliver)
-                {
-                  usp = rtcb->xcp.saved_regs[REG_SP];
-                }
-              else
-                {
-                  usp = rtcb->xcp.regs[REG_SP];
-                }
+              usp = rtcb->xcp.saved_regs[REG_SP];
 
               /* Create a frame for info and copy the kernel info */
 
@@ -411,9 +402,8 @@ int riscv_swint(int irq, void *context, void *arg)
 
               /* Now set the updated SP and user copy of "info" to A2 */
 
-              rtcb->xcp.kstkptr = (uintptr_t *)regs[REG_SP];
-              regs[REG_SP]      = usp;
-              regs[REG_A2]      = usp;
+              regs[REG_SP] = usp;
+              regs[REG_A2] = usp;
             }
 #endif
         }
@@ -443,9 +433,8 @@ int riscv_swint(int irq, void *context, void *arg)
           rtcb->xcp.sigreturn  = 0;
 
 #ifdef CONFIG_ARCH_KERNEL_STACK
-          /* We must enter here be using the user stack.  We need to switch
-           * to back to the kernel user stack before returning to the kernel
-           * mode signal trampoline.
+          /* We must restore the original kernel stack pointer before
+           * returning to the kernel mode signal trampoline.
            */
 
           if (rtcb->xcp.kstack != NULL)
@@ -453,7 +442,7 @@ int riscv_swint(int irq, void *context, void *arg)
               DEBUGASSERT(rtcb->xcp.kstkptr != NULL);
 
               regs[REG_SP]      = (uintptr_t)rtcb->xcp.kstkptr;
-              rtcb->xcp.kstkptr = NULL;
+              rtcb->xcp.kstkptr = rtcb->xcp.ktopstk;
             }
 #endif
         }
@@ -508,22 +497,15 @@ int riscv_swint(int irq, void *context, void *arg)
 #endif
 
 #ifdef CONFIG_ARCH_KERNEL_STACK
-          /* If this is the first SYSCALL and if there is an allocated
-           * kernel stack, then switch to the kernel stack.
+          /* If this is the first level system call, we must store the user
+           * stack pointer so it doesn't get lost.
            */
 
           if (index == 0 && rtcb->xcp.kstack != NULL)
             {
+              DEBUGASSERT(rtcb->xcp.ustkptr == NULL);
               rtcb->xcp.ustkptr = (uintptr_t *)regs[REG_SP];
-              if (rtcb->xcp.kstkptr != NULL)
-                {
-                  regs[REG_SP]  = (uintptr_t)rtcb->xcp.kstkptr;
-                }
-              else
-                {
-                  regs[REG_SP]  = (uintptr_t)rtcb->xcp.kstack +
-                                  ARCH_KERNEL_STACKSIZE;
-                }
+              regs[REG_SP]      = (uintptr_t)regs;
             }
 #endif
         }
