@@ -35,6 +35,7 @@
 #include <assert.h>
 #include <debug.h>
 #include <errno.h>
+#include <sys/param.h>
 #include <sys/types.h>
 
 #include "chip.h"
@@ -74,10 +75,6 @@
 
 #define RTC_MODULE_SLEEP_PREPARE_CYCLES (6)
 
-#ifndef MAX
-#define MAX(a,b) a > b ? a : b
-#endif
-
 /* Time from VDD_SDIO power up to first flash read in ROM code */
 
 #define VDD_SDIO_POWERUP_TO_FLASH_READ_US (700)
@@ -1193,4 +1190,4 @@ uint32_t IRAM_ATTR esp32c3_pm_lockstatus(void)
   return pm_wakelock;
 }
 
-#endif /* CONFIG_PM */
\ No newline at end of file
+#endif /* CONFIG_PM */
