@@ -47,7 +47,7 @@
 #include "esp_irq.h"
 #include "esp_lowputc.h"
 
-#include "clk_tree.h"
+#include "esp_clk_tree.h"
 #include "hal/uart_hal.h"
 #include "soc/clk_tree_defs.h"
 
@@ -78,7 +78,7 @@
 #    define CONSOLE_DEV     g_uart0_dev     /* UART0 is console */
 #    define TTYS0_DEV       g_uart0_dev     /* UART0 is ttyS0 */
 #    define UART0_ASSIGNED      1
-# elif defined(CONFIG_UART1_SERIAL_CONSOLE)
+#  elif defined(CONFIG_UART1_SERIAL_CONSOLE)
 #    define CONSOLE_DEV         g_uart1_dev  /* UART1 is console */
 #    define TTYS0_DEV           g_uart1_dev  /* UART1 is ttyS0 */
 #    define UART1_ASSIGNED      1
@@ -367,8 +367,8 @@ static int esp_setup(uart_dev_t *dev)
 
   esp_lowputc_enable_sysclk(priv);
 
-  clk_tree_src_get_freq_hz((soc_module_clk_t)UART_SCLK_DEFAULT,
-                           CLK_TREE_SRC_FREQ_PRECISION_CACHED,
+  esp_clk_tree_src_get_freq_hz((soc_module_clk_t)UART_SCLK_DEFAULT,
+                           ESP_CLK_TREE_SRC_FREQ_PRECISION_CACHED,
                            &sclk_freq);
 
   /* Initialize UART module */
@@ -493,10 +493,6 @@ static int esp_attach(uart_dev_t *dev)
 
   priv->cpuint = esp_setup_irq(priv->source, priv->int_pri,
                                ESP_IRQ_TRIGGER_LEVEL);
-  if (priv->cpuint < 0)
-    {
-      return priv->cpuint;
-    }
 
   /* Attach and enable the IRQ */
 
