@@ -148,10 +148,6 @@ static const struct file_operations g_himemfops =
   himem_write,      /* write */
   NULL,             /* seek */
   himem_ioctl,      /* ioctl */
-  NULL              /* poll */
-#ifndef CONFIG_DISABLE_PSEUDOFS_OPERATIONS
-  , NULL            /* unlink */
-#endif
 };
 
 /****************************************************************************
