@@ -34,6 +34,7 @@
 #include <assert.h>
 #include <debug.h>
 #include <errno.h>
+#include <sys/param.h>
 #include <sys/time.h>
 #include "hardware/esp32_rtccntl.h"
 #include "hardware/esp32_uart.h"
@@ -65,10 +66,6 @@
 
 #define LIGHT_SLEEP_MIN_TIME_US    200
 
-#ifndef MAX
-#define MAX(a,b) a > b ? a : b
-#endif
-
 /* Time from VDD_SDIO power up to first flash read in ROM code */
 
 #define VDD_SDIO_POWERUP_TO_FLASH_READ_US 700
@@ -1170,4 +1167,4 @@ uint32_t IRAM_ATTR esp32_pm_lockstatus(void)
   return pm_wakelock;
 }
 
-#endif /* CONFIG_PM */
\ No newline at end of file
+#endif /* CONFIG_PM */
