@@ -223,7 +223,7 @@ static const struct wlan_ops g_sta_ops =
   .event      = esp_wifi_notify_subscribe,
   .stop       = esp_wifi_sta_stop
 };
-#endif
+#endif /* ESP32_WLAN_HAS_STA */
 
 #ifdef ESP32_WLAN_HAS_SOFTAP
 static const struct wlan_ops g_softap_ops =
@@ -246,7 +246,7 @@ static const struct wlan_ops g_softap_ops =
   .event      = esp_wifi_notify_subscribe,
   .stop       = esp_wifi_softap_stop
 };
-#endif
+#endif /* ESP32_WLAN_HAS_SOFTAP */
 
 /****************************************************************************
  * Private Function Prototypes
@@ -1664,6 +1664,7 @@ static int esp32_net_initialize(int devno, uint8_t *mac_addr,
   return OK;
 }
 
+#ifdef ESP32_WLAN_HAS_STA
 /****************************************************************************
  * Function: wlan_sta_rx_done
  *
@@ -1681,7 +1682,6 @@ static int esp32_net_initialize(int devno, uint8_t *mac_addr,
  *
  ****************************************************************************/
 
-#ifdef ESP32_WLAN_HAS_STA
 static int wlan_sta_rx_done(void *buffer, uint16_t len, void *eb)
 {
   struct wlan_priv_s *priv = &g_wlan_priv[ESP32_WLAN_STA_DEVNO];
@@ -1712,8 +1712,9 @@ static void wlan_sta_tx_done(uint8_t *data, uint16_t *len, bool status)
 
   wlan_tx_done(priv);
 }
-#endif
+#endif /* ESP32_WLAN_HAS_STA */
 
+#ifdef ESP32_WLAN_HAS_SOFTAP
 /****************************************************************************
  * Function: wlan_softap_rx_done
  *
@@ -1731,7 +1732,6 @@ static void wlan_sta_tx_done(uint8_t *data, uint16_t *len, bool status)
  *
  ****************************************************************************/
 
-#ifdef ESP32_WLAN_HAS_SOFTAP
 static int wlan_softap_rx_done(void *buffer, uint16_t len, void *eb)
 {
   struct wlan_priv_s *priv = &g_wlan_priv[ESP32_WLAN_SOFTAP_DEVNO];
@@ -1763,12 +1763,46 @@ static void wlan_softap_tx_done(uint8_t *data, uint16_t *len, bool status)
 
   wlan_tx_done(priv);
 }
-#endif
+#endif /* ESP32_WLAN_HAS_SOFTAP */
 
 /****************************************************************************
  * Public Functions
  ****************************************************************************/
 
+/****************************************************************************
+ * Name: esp32_wlan_sta_set_linkstatus
+ *
+ * Description:
+ *   Set Wi-Fi station link status
+ *
+ * Parameters:
+ *   linkstatus - true Notifies the networking layer about an available
+ *                carrier, false Notifies the networking layer about an
+ *                disappeared carrier.
+ *
+ * Returned Value:
+ *   OK on success; Negated errno on failure.
+ *
+ ****************************************************************************/
+
+#ifdef ESP32_WLAN_HAS_STA
+int esp32_wlan_sta_set_linkstatus(bool linkstatus)
+{
+  int ret = -EINVAL;
+  struct wlan_priv_s *priv = &g_wlan_priv[ESP32_WLAN_STA_DEVNO];
+
+  if (linkstatus)
+    {
+      ret = netdev_carrier_on(&priv->dev);
+    }
+  else
+    {
+      ret = netdev_carrier_off(&priv->dev);
+    }
+
+  return ret;
+}
+
 /****************************************************************************
  * Name: esp32_wlan_sta_initialize
  *
@@ -1783,7 +1817,6 @@ static void wlan_softap_tx_done(uint8_t *data, uint16_t *len, bool status)
  *
  ****************************************************************************/
 
-#ifdef ESP32_WLAN_HAS_STA
 int esp32_wlan_sta_initialize(void)
 {
   int ret;
@@ -1827,8 +1860,9 @@ int esp32_wlan_sta_initialize(void)
 
   return OK;
 }
-#endif
+#endif /* ESP32_WLAN_HAS_STA */
 
+#ifdef ESP32_WLAN_HAS_SOFTAP
 /****************************************************************************
  * Name: esp32_wlan_softap_initialize
  *
@@ -1843,7 +1877,6 @@ int esp32_wlan_sta_initialize(void)
  *
  ****************************************************************************/
 
-#ifdef ESP32_WLAN_HAS_SOFTAP
 int esp32_wlan_softap_initialize(void)
 {
   int ret;
@@ -1888,6 +1921,6 @@ int esp32_wlan_softap_initialize(void)
 
   return OK;
 }
-#endif
+#endif /* ESP32_WLAN_HAS_SOFTAP */
 
 #endif  /* CONFIG_ESP32_WIFI */
