@@ -136,8 +136,6 @@ static const struct z180_dev_s g_scc_priv =
 static uart_dev_t g_scc_port =
 {
   0,                           /* open_count */
-  false,                       /* xmitwaiting */
-  false,                       /* recvwaiting */
 #ifdef CONFIG_Z180_SCC_SERIAL_CONSOLE
   true,                        /* isconsole */
 #else
@@ -182,8 +180,6 @@ static const struct z180_dev_s g_escca_priv =
 static uart_dev_t g_escca_port =
 {
   0,                             /* open_count */
-  false,                         /* xmitwaiting */
-  false,                         /* recvwaiting */
 #ifdef CONFIG_Z180_ESCCA_SERIAL_CONSOLE
   true,                          /* isconsole */
 #else
@@ -228,8 +224,6 @@ static const struct z180_dev_s g_esccb_priv =
 static uart_dev_t g_escca_port =
 {
   0,                           /* open_count */
-  false,                       /* xmitwaiting */
-  false,                       /* recvwaiting */
 #ifdef CONFIG_Z180_ESCCA_SERIAL_CONSOLE
   true,                        /* isconsole */
 #else
@@ -289,10 +283,10 @@ static uart_dev_t g_escca_port =
 #  define TTYS0_DEV       g_escca_port
 #  if defined(CONFIG_Z180_ESCCB)
 #    define TTYS1_DEV     g_esccb_port
-# endif
+#  endif
 
 #elif defined(CONFIG_Z180_ESCCB)
-# define TTYS0_DEV       g_esccb_port
+#  define TTYS0_DEV       g_esccb_port
 #endif
 
 /****************************************************************************
