@@ -57,6 +57,7 @@
 
 #include <nuttx/config.h>
 
+#include <sys/param.h>
 #include <sys/types.h>
 #include <stdint.h>
 #include <stdbool.h>
@@ -97,16 +98,6 @@
 #  define CONFIG_LCD_MAXPOWER 100
 #endif
 
-/* The ever-present MIN/MAX macros ******************************************/
-
-#ifndef MIN
-#  define MIN(a,b) (a < b ? a : b)
-#endif
-
-#ifndef MAX
-#  define MAX(a,b) (a > b ? a : b)
-#endif
-
 /* LCD **********************************************************************/
 
 #define LCD_NROWS        2
@@ -181,10 +172,9 @@ static const struct file_operations g_lcdops =
   lcd_write,     /* write */
   NULL,          /* seek */
   lcd_ioctl,     /* ioctl */
+  NULL,          /* mmap */
+  NULL,          /* truncate */
   lcd_poll       /* poll */
-#ifndef CONFIG_DISABLE_PSEUDOFS_OPERATIONS
-  , NULL         /* unlink */
-#endif
 };
 
 /* This is the driver state structure */
