@@ -70,7 +70,7 @@ static int     bch_unlink(FAR struct inode *inode);
  * Public Data
  ****************************************************************************/
 
-const struct file_operations bch_fops =
+const struct file_operations g_bch_fops =
 {
   bch_open,    /* open */
   bch_close,   /* close */
