@@ -170,8 +170,8 @@ static int efuse_ioctl(FAR struct file *filep, int cmd, unsigned long arg)
 
     case EFUSEIOC_READ_FIELD:
       {
-        FAR struct efuse_param *param =
-                   (FAR struct efuse_param *)((uintptr_t)arg);
+        FAR struct efuse_param_s *param =
+                   (FAR struct efuse_param_s *)((uintptr_t)arg);
 
         /* Read the efuse */
 
@@ -200,8 +200,8 @@ static int efuse_ioctl(FAR struct file *filep, int cmd, unsigned long arg)
 
     case EFUSEIOC_WRITE_FIELD:
       {
-        FAR struct efuse_param *param =
-                   (FAR struct efuse_param *)((uintptr_t)arg);
+        FAR struct efuse_param_s *param =
+                   (FAR struct efuse_param_s *)((uintptr_t)arg);
 
         /* Write the efuse */
 
