@@ -104,7 +104,7 @@ static int i2schar_ioctl(FAR struct file *filep, int cmd, unsigned long arg);
  * Private Data
  ****************************************************************************/
 
-static const struct file_operations i2schar_fops =
+static const struct file_operations g_i2schar_fops =
 {
   NULL,                 /* open  */
   NULL,                 /* close */
@@ -425,7 +425,7 @@ int i2schar_register(FAR struct i2s_dev_s *i2s, int minor)
       /* Create the character device name */
 
       snprintf(devname, DEVNAME_FMTLEN, DEVNAME_FMT, minor);
-      ret = register_driver(devname, &i2schar_fops, 0666, priv);
+      ret = register_driver(devname, &g_i2schar_fops, 0666, priv);
       if (ret < 0)
         {
           /* Free the device structure if we failed to create the character
