@@ -1011,7 +1011,7 @@ static int sst25_erase(FAR struct mtd_dev_s *dev,
                        size_t nblocks)
 {
 #ifdef CONFIG_SST25_READONLY
-  return -EACESS
+  return -EACCES;
 #else
   FAR struct sst25_dev_s *priv = (FAR struct sst25_dev_s *)dev;
   size_t blocksleft = nblocks;
