@@ -467,7 +467,7 @@ static inline int note_isenabled_dump(uint32_t tag)
   /* If the dump trace is disabled, do nothing. */
 
   if (!(g_note_filter.mode.flag & NOTE_FILTER_MODE_FLAG_DUMP) ||
-      NOTE_FILTER_DUMPMASK_ISSET(tag, &g_note_filter.tag_mask))
+      NOTE_FILTER_TAGMASK_ISSET(tag, &g_note_filter.tag_mask))
     {
       return false;
     }
@@ -1876,7 +1876,7 @@ void sched_note_filter_irq(FAR struct note_filter_irq_s *oldf,
  * Name: sched_note_filter_tag
  *
  * Description:
- *   Set and get tsg filter setting
+ *   Set and get tag filter setting
  *   (Same as NOTECTL_GETDUMPFILTER / NOTECTL_SETDUMPFILTER ioctls)
  *
  * Input Parameters:
@@ -1893,8 +1893,8 @@ void sched_note_filter_irq(FAR struct note_filter_irq_s *oldf,
  ****************************************************************************/
 
 #  ifdef CONFIG_SCHED_INSTRUMENTATION_DUMP
-void sched_note_filter_dump(FAR struct note_filter_tag_s *oldf,
-                            FAR struct note_filter_tag_s *newf)
+void sched_note_filter_tag(FAR struct note_filter_tag_s *oldf,
+                           FAR struct note_filter_tag_s *newf)
 {
   irqstate_t falgs;
 
@@ -1987,3 +1987,26 @@ int note_driver_register(FAR struct note_driver_s *driver)
 
   return -ENOMEM;
 }
+
+#ifdef CONFIG_SCHED_INSTRUMENTATION_FUNCTION
+
+/****************************************************************************
+ * Name: __cyg_profile_func_enter
+ ****************************************************************************/
+
+void noinstrument_function
+__cyg_profile_func_enter(void *this_fn, void *call_site)
+{
+  sched_note_string_ip(NOTE_TAG_ALWAYS, (uintptr_t)this_fn, "B");
+}
+
+/****************************************************************************
+ * Name: __cyg_profile_func_exit
+ ****************************************************************************/
+
+void noinstrument_function
+__cyg_profile_func_exit(void *this_fn, void *call_site)
+{
+  sched_note_string_ip(NOTE_TAG_ALWAYS, (uintptr_t)this_fn, "E");
+}
+#endif
