@@ -32,6 +32,7 @@
 
 #include <nuttx/config.h>
 
+#include <sys/param.h>
 #include <sys/types.h>
 
 #include <unistd.h>
@@ -63,12 +64,6 @@
  * Pre-processor Definitions
  ****************************************************************************/
 
-/* Helpers ******************************************************************/
-
-#ifndef MIN
-#  define MIN(a,b) ((a) < (b) ? (a) : (b))
-#endif
-
 /* The CRC function expects to see address bytes as they appear on the wire */
 
 #define WR_ADDR(a)  ((a) << 1)
