@@ -100,7 +100,7 @@ struct sensor_rpmsg_ept_s
   struct rpmsg_endpoint          ept;
   FAR struct rpmsg_device       *rdev;
   struct work_s                  work;
-  mutex_t                        lock;
+  rmutex_t                       lock;
   FAR void                      *buffer;
   uint64_t                       expire;
   uint32_t                       space;
@@ -149,6 +149,7 @@ struct sensor_rpmsg_advsub_s
 struct sensor_rpmsg_cell_s
 {
   uint64_t                       cookie;
+  uint32_t                       nbuffer;
   uint32_t                       len;
   char                           data[0];
 };
@@ -278,8 +279,8 @@ static const rpmsg_ept_cb g_sensor_rpmsg_handler[] =
 
 static struct list_node g_devlist = LIST_INITIAL_VALUE(g_devlist);
 static struct list_node g_eptlist = LIST_INITIAL_VALUE(g_eptlist);
-static mutex_t g_ept_lock = NXMUTEX_INITIALIZER;
-static mutex_t g_dev_lock = NXMUTEX_INITIALIZER;
+static rmutex_t g_ept_lock = NXRMUTEX_INITIALIZER;
+static rmutex_t g_dev_lock = NXRMUTEX_INITIALIZER;
 
 /****************************************************************************
  * Private Functions
@@ -332,14 +333,14 @@ static void sensor_rpmsg_advsub(FAR struct sensor_rpmsg_dev_s *dev,
 
   /* Broadcast advertise/subscribe message to all ready ept */
 
-  nxmutex_lock(&g_ept_lock);
+  nxrmutex_lock(&g_ept_lock);
   list_for_every_entry(&g_eptlist, sre, struct sensor_rpmsg_ept_s,
                        node)
     {
       sensor_rpmsg_advsub_one(dev, &sre->ept, command);
     }
 
-  nxmutex_unlock(&g_ept_lock);
+  nxrmutex_unlock(&g_ept_lock);
 }
 
 static int sensor_rpmsg_ioctl(FAR struct sensor_rpmsg_dev_s *dev,
@@ -710,14 +711,14 @@ static void sensor_rpmsg_data_worker(FAR void *arg)
 {
   FAR struct sensor_rpmsg_ept_s *sre = arg;
 
-  nxmutex_lock(&sre->lock);
+  nxrmutex_lock(&sre->lock);
   if (sre->buffer)
     {
       rpmsg_send_nocopy(&sre->ept, sre->buffer, sre->written);
       sre->buffer = NULL;
     }
 
-  nxmutex_unlock(&sre->lock);
+  nxrmutex_unlock(&sre->lock);
 }
 
 static void sensor_rpmsg_push_event_one(FAR struct sensor_rpmsg_dev_s *dev,
@@ -745,7 +746,7 @@ static void sensor_rpmsg_push_event_one(FAR struct sensor_rpmsg_dev_s *dev,
     }
 
   sre = container_of(stub->ept, struct sensor_rpmsg_ept_s, ept);
-  nxmutex_lock(&sre->lock);
+  nxrmutex_lock(&sre->lock);
 
   /* Cancel work to fill new data to buffer */
 
@@ -780,7 +781,7 @@ static void sensor_rpmsg_push_event_one(FAR struct sensor_rpmsg_dev_s *dev,
             {
               snerr("ERROR: push event get buffer failed:%s\n",
                     rpmsg_get_cpuname(sre->ept.rdev));
-              nxmutex_unlock(&sre->lock);
+              nxrmutex_unlock(&sre->lock);
               return;
             }
 
@@ -799,6 +800,8 @@ static void sensor_rpmsg_push_event_one(FAR struct sensor_rpmsg_dev_s *dev,
 
       cell->len     = ret;
       cell->cookie  = stub->cookie;
+      cell->nbuffer = dev->lower.nbuffer;
+
       sre->written += (sizeof(*cell) + ret + 0x7) & ~0x7;
     }
 
@@ -829,7 +832,7 @@ static void sensor_rpmsg_push_event_one(FAR struct sensor_rpmsg_dev_s *dev,
                  (sre->expire - now) / USEC_PER_TICK);
     }
 
-  nxmutex_unlock(&sre->lock);
+  nxrmutex_unlock(&sre->lock);
 }
 
 static ssize_t sensor_rpmsg_push_event(FAR void *priv, FAR const void *data,
@@ -867,17 +870,17 @@ sensor_rpmsg_find_dev(FAR const char *path)
 {
   FAR struct sensor_rpmsg_dev_s *dev;
 
-  nxmutex_lock(&g_dev_lock);
+  nxrmutex_lock(&g_dev_lock);
   list_for_every_entry(&g_devlist, dev, struct sensor_rpmsg_dev_s, node)
     {
       if (strcmp(dev->path, path) == 0)
         {
-          nxmutex_unlock(&g_dev_lock);
+          nxrmutex_unlock(&g_dev_lock);
           return dev;
         }
     }
 
-  nxmutex_unlock(&g_dev_lock);
+  nxrmutex_unlock(&g_dev_lock);
   return NULL;
 }
 
@@ -1067,6 +1070,19 @@ static int sensor_rpmsg_publish_handler(FAR struct rpmsg_endpoint *ept,
       cell = (FAR struct sensor_rpmsg_cell_s *)
              ((FAR char *)data + written);
       dev = (FAR struct sensor_rpmsg_dev_s *)(uintptr_t)cell->cookie;
+      if (cell->nbuffer > dev->lower.nbuffer)
+        {
+          struct file file;
+          int ret;
+
+          ret = file_open(&file, dev->path, SENSOR_REMOTE);
+          if (ret >= 0)
+            {
+              file_ioctl(&file, SNIOC_SET_BUFFER_NUMBER, cell->nbuffer);
+              file_close(&file);
+            }
+        }
+
       dev->push_event(dev->upper, cell->data, cell->len);
       written += sizeof(*cell) + cell->len + 0x7;
       written &= ~0x7;
@@ -1161,7 +1177,7 @@ static void sensor_rpmsg_ns_unbind_cb(FAR struct rpmsg_endpoint *ept)
    * destoryed.
    */
 
-  nxmutex_lock(&g_dev_lock);
+  nxrmutex_lock(&g_dev_lock);
   list_for_every_entry(&g_devlist, dev,
                        struct sensor_rpmsg_dev_s, node)
     {
@@ -1189,13 +1205,13 @@ static void sensor_rpmsg_ns_unbind_cb(FAR struct rpmsg_endpoint *ept)
       sensor_rpmsg_unlock(dev);
     }
 
-  nxmutex_unlock(&g_dev_lock);
+  nxrmutex_unlock(&g_dev_lock);
 
-  nxmutex_lock(&g_ept_lock);
+  nxrmutex_lock(&g_ept_lock);
   list_delete(&sre->node);
-  nxmutex_unlock(&g_ept_lock);
+  nxrmutex_unlock(&g_ept_lock);
 
-  nxmutex_destroy(&sre->lock);
+  nxrmutex_destroy(&sre->lock);
   kmm_free(sre);
   rpmsg_destroy_ept(ept);
 }
@@ -1207,13 +1223,13 @@ static void sensor_rpmsg_device_ns_bound(FAR struct rpmsg_endpoint *ept)
 
   sre = container_of(ept, struct sensor_rpmsg_ept_s, ept);
 
-  nxmutex_lock(&g_ept_lock);
+  nxrmutex_lock(&g_ept_lock);
   list_add_tail(&g_eptlist, &sre->node);
-  nxmutex_unlock(&g_ept_lock);
+  nxrmutex_unlock(&g_ept_lock);
 
   /* Broadcast all device to ready ept */
 
-  nxmutex_lock(&g_dev_lock);
+  nxrmutex_lock(&g_dev_lock);
   list_for_every_entry(&g_devlist, dev,
                        struct sensor_rpmsg_dev_s, node)
     {
@@ -1231,7 +1247,7 @@ static void sensor_rpmsg_device_ns_bound(FAR struct rpmsg_endpoint *ept)
       sensor_rpmsg_unlock(dev);
     }
 
-  nxmutex_unlock(&g_dev_lock);
+  nxrmutex_unlock(&g_dev_lock);
 }
 
 static void sensor_rpmsg_device_created(FAR struct rpmsg_device *rdev,
@@ -1247,14 +1263,14 @@ static void sensor_rpmsg_device_created(FAR struct rpmsg_device *rdev,
 
   sre->rdev = rdev;
   sre->ept.priv = sre;
-  nxmutex_init(&sre->lock);
+  nxrmutex_init(&sre->lock);
   sre->ept.ns_bound_cb = sensor_rpmsg_device_ns_bound;
   if (rpmsg_create_ept(&sre->ept, rdev, SENSOR_RPMSG_EPT_NAME,
                        RPMSG_ADDR_ANY, RPMSG_ADDR_ANY,
                        sensor_rpmsg_ept_cb,
                        sensor_rpmsg_ns_unbind_cb) < 0)
     {
-      nxmutex_destroy(&sre->lock);
+      nxrmutex_destroy(&sre->lock);
       kmm_free(sre);
     }
 }
@@ -1284,13 +1300,15 @@ sensor_rpmsg_register(FAR struct sensor_lowerhalf_s *lower,
 {
   FAR struct sensor_rpmsg_ept_s *sre;
   FAR struct sensor_rpmsg_dev_s *dev;
+  size_t size;
 
   if (lower->ops->fetch)
     {
       return lower;
     }
 
-  dev = kmm_zalloc(sizeof(*dev) + strlen(path));
+  size = strlen(path);
+  dev = kmm_zalloc(sizeof(*dev) + size);
   if (!dev)
     {
       return NULL;
@@ -1300,7 +1318,7 @@ sensor_rpmsg_register(FAR struct sensor_lowerhalf_s *lower,
 
   list_initialize(&dev->stublist);
   list_initialize(&dev->proxylist);
-  strcpy(dev->path, path);
+  strlcpy(dev->path, path, size + 1);
 
   dev->nadvertisers   = !!lower->ops->activate;
   dev->push_event     = lower->push_event;
@@ -1313,19 +1331,19 @@ sensor_rpmsg_register(FAR struct sensor_lowerhalf_s *lower,
 
   /* If openamp is ready, send advertisement to remote proc */
 
-  nxmutex_lock(&g_dev_lock);
+  nxrmutex_lock(&g_dev_lock);
   list_add_tail(&g_devlist, &dev->node);
-  nxmutex_unlock(&g_dev_lock);
+  nxrmutex_unlock(&g_dev_lock);
   if (lower->ops->activate)
     {
-      nxmutex_lock(&g_ept_lock);
+      nxrmutex_lock(&g_ept_lock);
       list_for_every_entry(&g_eptlist, sre, struct sensor_rpmsg_ept_s,
                            node)
         {
           sensor_rpmsg_advsub_one(dev, &sre->ept, SENSOR_RPMSG_ADVERTISE);
         }
 
-      nxmutex_unlock(&g_ept_lock);
+      nxrmutex_unlock(&g_ept_lock);
     }
 
   return &dev->lower;
@@ -1351,9 +1369,9 @@ void sensor_rpmsg_unregister(FAR struct sensor_lowerhalf_s *lower)
       return;
     }
 
-  nxmutex_lock(&g_dev_lock);
+  nxrmutex_lock(&g_dev_lock);
   list_delete(&dev->node);
-  nxmutex_unlock(&g_dev_lock);
+  nxrmutex_unlock(&g_dev_lock);
 
   kmm_free(dev);
 }
