@@ -155,10 +155,6 @@ static const struct file_operations g_t67xxfops =
   t67xx_write,    /* write */
   NULL,           /* seek */
   t67xx_ioctl,    /* ioctl */
-  NULL            /* poll */
-#ifndef CONFIG_DISABLE_PSEUDOFS_OPERATIONS
-  , NULL          /* unlink */
-#endif
 };
 
 /****************************************************************************
