@@ -114,10 +114,9 @@ static const struct file_operations g_ramlogfops =
   ramlog_file_write, /* write */
   NULL,              /* seek */
   ramlog_file_ioctl, /* ioctl */
+  NULL,              /* mmap */
+  NULL,              /* truncate */
   ramlog_file_poll   /* poll */
-#ifndef CONFIG_DISABLE_PSEUDOFS_OPERATIONS
-  , NULL             /* unlink */
-#endif
 };
 
 /* This is the pre-allocated buffer used for the console RAM log and/or
