@@ -54,8 +54,6 @@
  * Pre-processor Definitions
  ****************************************************************************/
 
-#define DEBUG
-
 /* Work queue support is required. */
 
 #if !defined(CONFIG_SCHED_WORKQUEUE)
@@ -78,25 +76,25 @@
  */
 
 #ifndef VIRTIO_NET_NINTERFACES
-# define VIRTIO_NET_NINTERFACES 1
+#  define VIRTIO_NET_NINTERFACES 1
 #endif
 
 /* TX timeout = 1 minute */
 
 #define VIRTNET_TXTIMEOUT (60*CLK_TCK)
 
+/* virtio net related definition */
+
+#define VIRTIO_NET_HDRLEN 10
+
 /* Packet buffer size */
 
-#define PKTBUF_SIZE (MAX_NETDEV_PKTSIZE + CONFIG_NET_GUARDSIZE)
+#define PKTBUF_SIZE (VIRTIO_NET_HDRLEN + MAX_NETDEV_PKTSIZE + CONFIG_NET_GUARDSIZE)
 
 /* This is a helper pointer for accessing the contents of Ethernet header */
 
 #define BUF ((struct eth_hdr_s *)priv->vnet_dev.d_buf)
 
-/* virtio net related definition */
-
-#define VIRTIO_NET_HDRLEN 10
-
 #define VIRTIO_NET_Q_RX 0
 #define VIRTIO_NET_Q_TX 1
 
@@ -183,10 +181,7 @@ static int  virtnet_txpoll(FAR struct net_driver_s *dev);
 
 static void virtnet_reply(FAR struct virtnet_driver_s *priv);
 static void virtnet_receive(FAR struct virtnet_driver_s *priv);
-
-#ifdef TODO
-static void virtnet_txdone(FAR struct virtnet_driver_s *priv);
-#endif
+static void virtnet_rxdispatch(FAR struct virtnet_driver_s *priv);
 
 static void virtnet_interrupt_work(FAR void *arg);
 static int  virtnet_interrupt(int irq, FAR void *context, FAR void *arg);
@@ -220,8 +215,6 @@ static int  virtnet_ioctl(FAR struct net_driver_s *dev, int cmd,
                           unsigned long arg);
 #endif
 
-static void virtnet_rxdispatch(FAR struct virtnet_driver_s *priv);
-
 /****************************************************************************
  * Private Functions
  ****************************************************************************/
@@ -266,10 +259,9 @@ static void virtnet_add_packets_to_rxq(FAR struct virtnet_driver_s *priv)
   FAR struct virtqueue *rxq = priv->rxq;
   FAR uint8_t  *pkt;
   uint16_t d1;
-  uint16_t d2;
   uint32_t i;
 
-  vrtinfo("+++ rxq->len=%" PRId32 "  rxq->avail-idx=%d \n",
+  vrtinfo("+++ rxq->len=%" PRId32 "  rxq->avail->idx=%d \n",
           rxq->len, rxq->avail->idx);
   DEBUGASSERT(rxq->avail->idx == 0);
 
@@ -278,33 +270,26 @@ static void virtnet_add_packets_to_rxq(FAR struct virtnet_driver_s *priv)
       pkt = kmm_memalign(16, PKTBUF_SIZE);
       ASSERT(pkt);
 
-      /* Allocate new descriptors for header and packet */
+      /* Allocate a new descriptor for header + packet */
 
-      d1 = virtq_alloc_desc(rxq, (i * 2),  (FAR void *)&g_hdr);
-      d2 = virtq_alloc_desc(rxq, (i * 2) + 1, pkt);
+      d1 = virtq_alloc_desc(rxq, i, pkt);
 
-      /* Set up the descriptor for header */
+      /* Set up the descriptor */
 
-      rxq->desc[d1].len   = VIRTIO_NET_HDRLEN;
-      rxq->desc[d1].flags = VIRTQ_DESC_F_WRITE | VIRTQ_DESC_F_NEXT;
-      rxq->desc[d1].next  = d2;
+      rxq->desc[d1].len   = PKTBUF_SIZE;
+      rxq->desc[d1].flags = VIRTQ_DESC_F_WRITE;
 
-      /* Set up the descriptor for packet */
-
-      rxq->desc[d2].len   = PKTBUF_SIZE;
-      rxq->desc[d2].flags = VIRTQ_DESC_F_WRITE;
-
-      /* Set the first descriptor to the avail->ring */
+      /* Set the descriptor to avail->ring */
 
       rxq->avail->ring[i] = d1;
 
-      /* Increment the avail->idx for each two descriptors */
+      /* Increment the avail->idx */
 
       virtio_mb();
       rxq->avail->idx += 1;
     }
 
-  vrtinfo("+++ virtq->avail-idx=%d \n", rxq->avail->idx);
+  vrtinfo("+++ virtq->avail->idx=%d \n", rxq->avail->idx);
   vrtinfo("+++ virtq->used->idx=%d \n", rxq->used->idx);
 }
 
@@ -338,11 +323,6 @@ static int virtnet_transmit(FAR struct virtnet_driver_s *priv)
    * address=priv->vnet_dev.d_buf, length=priv->vnet_dev.d_len
    */
 
-  /* Verify that the hardware is ready to send another packet.  If we get
-   * here, then we are committed to sending a packet; Higher level logic
-   * must have assured that there is no transmission in progress.
-   */
-
   /* Increment statistics */
 
   NETDEV_TXPACKETS(priv->vnet_dev);
@@ -359,12 +339,12 @@ static int virtnet_transmit(FAR struct virtnet_driver_s *priv)
   d2 = virtq_alloc_desc(priv->txq, idx + 1, pkt);
   DEBUGASSERT(d1 != d2);
 
-  /* Set up the descriptor for header */
+  /* Set up the descriptor for packet */
 
   priv->txq->desc[d2].len   = len;
   priv->txq->desc[d2].flags = 0;
 
-  /* Set up the descriptor for packet */
+  /* Set up the descriptor for header */
 
   priv->txq->desc[d1].len   = VIRTIO_NET_HDRLEN;
   priv->txq->desc[d1].flags = VIRTQ_DESC_F_NEXT;
@@ -386,14 +366,18 @@ static int virtnet_transmit(FAR struct virtnet_driver_s *priv)
 
   vrtinfo("*** finish updating queue_notify\n");
 
-#ifdef TODO
-  /* Enable Tx interrupts */
-#endif
-
   /* Setup the TX timeout watchdog (perhaps restarting the timer) */
 
   wd_start(&priv->vnet_txtimeout, VIRTNET_TXTIMEOUT,
            virtnet_txtimeout_expiry, (wdparm_t)priv);
+
+  /* Wait for completion */
+
+  while (priv->txq->avail->idx != priv->txq->used->idx)
+    {
+      virtio_mb();
+    }
+
   return OK;
 }
 
@@ -413,7 +397,7 @@ static int virtnet_transmit(FAR struct virtnet_driver_s *priv)
  *   dev - Reference to the NuttX driver state structure
  *
  * Returned Value:
- *   OK on success; a negated errno on failure
+ *   Always OK
  *
  * Assumptions:
  *   The network is locked.
@@ -435,9 +419,11 @@ static int virtnet_txpoll(FAR struct net_driver_s *dev)
 
   virtnet_reply(priv);
 
-  /* Stop the poll now because we only have one tx buffer (g_pktbuf) */
+  /* NOTE: Since virtnet_transmit() now waits for TX completion,
+   * this method should return OK to continue.
+   */
 
-  return -EBUSY;
+  return OK;
 }
 
 /****************************************************************************
@@ -599,17 +585,16 @@ static void virtnet_receive(FAR struct virtnet_driver_s *priv)
   for (idx = priv->rxq->last_used_idx; idx != used; idx++)
     {
       uint16_t id  = idx % priv->rxq->len;
-      uint16_t d1  = priv->rxq->used->ring[id].id; /* index for header */
-      uint16_t d2  = priv->rxq->desc[d1].next;     /* index for packet */
+      uint16_t d1  = priv->rxq->used->ring[id].id; /* index for header + packet */
       uint32_t len = priv->rxq->used->ring[id].len;
-      DEBUGASSERT(d2 == (d1 + 1));
+      uint16_t flags = priv->rxq->desc[d1].flags;
 
-      vrtinfo("+++ idx=%d id=%d used->idx=%d: d1=%d d2=%d len=%" PRId32 "\n",
-              idx, id, priv->rxq->used->idx, d1, d2, len);
+      vrtinfo("+++ idx=%d id=%d used->idx=%d: d1=%d f=%d len=%" PRId32 "\n",
+              idx, id, priv->rxq->used->idx, d1, flags, len);
 
       /* Set the packet info to d_buf and set d_len */
 
-      priv->vnet_dev.d_buf = priv->rxq->desc_virt[d2];
+      priv->vnet_dev.d_buf = priv->rxq->desc_virt[d1] + VIRTIO_NET_HDRLEN;
       priv->vnet_dev.d_len = len - VIRTIO_NET_HDRLEN;
 
       vrtinfo("Receiving packet, pktlen: %d\n", priv->vnet_dev.d_len);
@@ -635,46 +620,6 @@ static void virtnet_receive(FAR struct virtnet_driver_s *priv)
   priv->vnet_dev.d_buf = buf;
 }
 
-/****************************************************************************
- * Name: virtnet_txdone
- *
- * Description:
- *   An interrupt was received indicating that the last TX packet(s) is done
- *
- * Input Parameters:
- *   priv - Reference to the driver state structure
- *
- * Returned Value:
- *   None
- *
- * Assumptions:
- *   The network is locked.
- *
- ****************************************************************************/
-
-#ifdef TODO
-static void virtnet_txdone(FAR struct virtnet_driver_s *priv)
-{
-  /* Check for errors and update statistics */
-
-  NETDEV_TXDONE(priv->vnet_dev);
-
-  /* Check if there are pending transmissions */
-
-  /* If no further transmissions are pending, then cancel the TX timeout and
-   * disable further Tx interrupts.
-   */
-
-  wd_cancel(&priv->vnet_txtimeout);
-
-  /* And disable further TX interrupts. */
-
-  /* In any event, poll the network for new TX data */
-
-  devif_poll(&priv->vnet_dev, virtnet_txpoll);
-}
-#endif
-
 /****************************************************************************
  * Name: virtnet_interrupt_work
  *
@@ -704,24 +649,10 @@ static void virtnet_interrupt_work(FAR void *arg)
 
   net_lock();
 
-  /* Process pending Ethernet interrupts */
-
-  /* Handle interrupts according to status bit settings */
-
-  /* Check if we received an incoming packet, if so, call virtnet_receive() */
+  /* Process incoming packets */
 
   virtnet_receive(priv);
 
-  /* Check if a packet transmission just completed.
-   * If so, call virtnet_txdone.
-   * This may disable further Tx interrupts if there are no pending
-   * transmissions.
-   */
-
-#ifdef TODO
-  virtnet_txdone(priv);
-#endif
-
   net_unlock();
 
   if (priv->rxq->last_used_idx == priv->rxq->used->idx)
