@@ -39,6 +39,14 @@
 #include "littlefs/lfs.h"
 #include "littlefs/lfs_util.h"
 
+/****************************************************************************
+ * Pre-processor Definitions
+ ****************************************************************************/
+
+#ifndef CONFIG_C99_BOOL
+#  error littlefs requires CONFIG_C99_BOOL to be selected
+#endif
+
 /****************************************************************************
  * Private Types
  ****************************************************************************/
@@ -132,7 +140,7 @@ static int     littlefs_stat(FAR struct inode *mountpt,
  * with any compiler.
  */
 
-const struct mountpt_operations littlefs_operations =
+const struct mountpt_operations g_littlefs_operations =
 {
   littlefs_open,          /* open */
   littlefs_close,         /* close */
@@ -1234,7 +1242,6 @@ static int littlefs_statfs(FAR struct inode *mountpt, FAR struct statfs *buf)
 
   /* Return something for the file system description */
 
-  memset(buf, 0, sizeof(*buf));
   buf->f_type    = LITTLEFS_SUPER_MAGIC;
   buf->f_namelen = LFS_NAME_MAX;
   buf->f_bsize   = fs->cfg.block_size;
