@@ -27,6 +27,7 @@
 
 #include <nuttx/config.h>
 
+#include <sys/param.h>
 #include <sys/types.h>
 #include <stdint.h>
 #include <stdbool.h>
@@ -171,16 +172,6 @@
 
 #define NXFFS_NERASED             128
 
-/* Quasi-standard definitions */
-
-#ifndef MIN
-#  define MIN(a,b)                ((a) < (b) ? (a) : (b))
-#endif
-
-#ifndef MAX
-#  define MAX(a,b)                ((a) > (b) ? (a) : (b))
-#endif
-
 /****************************************************************************
  * Public Types
  ****************************************************************************/
