@@ -24,12 +24,22 @@
 
 #include <sys/mount.h>
 
+#include <assert.h>
+#include <stdio.h>
+
+#include "driver/driver.h"
 #include "partition.h"
 
 /****************************************************************************
  * Private Types
  ****************************************************************************/
 
+struct partition_register_s
+{
+  FAR struct partition_state_s *state;
+  FAR const char *dir;
+};
+
 typedef CODE int
   (*partition_parser_t)(FAR struct partition_state_s *state,
                         partition_handler_t handler,
@@ -39,6 +49,9 @@ typedef CODE int
  * Private Function Prototypes
  ****************************************************************************/
 
+static void register_partition(FAR struct partition_s *part,
+                               FAR void *arg);
+
 static int parse_partition(FAR struct partition_state_s *state,
                            partition_handler_t handler,
                            FAR void *arg);
@@ -68,6 +81,30 @@ static const partition_parser_t g_parser[] =
  * Private Functions
  ****************************************************************************/
 
+static void register_partition(FAR struct partition_s *part, FAR void *arg)
+{
+  if (part->name[0] != '\0')
+    {
+      FAR struct partition_register_s *reg = arg;
+      FAR struct partition_state_s *state = reg->state;
+      char path[PATH_MAX];
+
+      snprintf(path, sizeof(path), "%s/%s", reg->dir, part->name);
+      if (state->blk != NULL)
+        {
+          register_partition_with_inode(path, 0660, state->blk,
+                                        part->firstblock, part->nblocks);
+        }
+#ifdef CONFIG_MTD
+      else
+        {
+          register_partition_with_mtd(path, 0660, state->mtd,
+                                      part->firstblock, part->nblocks);
+        }
+#endif
+    }
+}
+
 /****************************************************************************
  * Name: parse_partition
  *
@@ -90,6 +127,16 @@ static int parse_partition(FAR struct partition_state_s *state,
 {
   int i;
   int ret = 0;
+  struct partition_register_s reg =
+  {
+    state, arg ? arg : "/dev"
+  };
+
+  if (handler == NULL)
+    {
+      handler = register_partition;
+      arg = &reg;
+    }
 
   for (i = 0; g_parser[i] != NULL; i++)
     {
