@@ -50,6 +50,7 @@
 
 #include <stddef.h>
 #include <stdbool.h>
+#include <sys/param.h>
 
 #include "spiffs.h"
 #include "spiffs_mtd.h"
@@ -369,14 +370,6 @@
 
 #define SPIFFS_VIS_NO_WRAP      (1<<2)
 
-#ifndef MIN
-#  define MIN(a,b) ((a) < (b) ? (a) : (b))
-#endif
-
-#ifndef MAX
-#  define MAX(a,b) ((a) > (b) ? (a) : (b))
-#endif
-
 /****************************************************************************
  * Public Types
  ****************************************************************************/
