@@ -82,7 +82,7 @@
 #define NUTTX_O_TRUNC           (1 << 5)  /* Delete contents */
 #define NUTTX_O_NONBLOCK        (1 << 6)  /* Don't wait for data */
 #define NUTTX_O_SYNC            (1 << 7)  /* Synchronize output on write */
-#define NUTTX_O_BINARY          (1 << 8)  /* Open the file in binary mode. */
+#define NUTTX_O_TEXT            (1 << 8)  /* Open the file in text (translated) mode. */
 #define NUTTX_O_DIRECT          (1 << 9)  /* Avoid caching, write directly to hardware */
 #define NUTTX_O_CLOEXEC         (1 << 10) /* Close on execute */
 #define NUTTX_O_DIRECTORY       (1 << 11) /* Must be a directory */
