@@ -29,6 +29,7 @@
 
 #include <sys/types.h>
 #include <stdbool.h>
+#include <malloc.h>
 
 /****************************************************************************
  * Pre-processor Definitions
@@ -98,6 +99,8 @@
 #  endif
 #endif
 
+#define mm_memdump_s malltask
+
 /****************************************************************************
  * Public Types
  ****************************************************************************/
@@ -117,6 +120,10 @@ extern "C"
 #define EXTERN extern
 #endif
 
+#if CONFIG_MM_BACKTRACE >= 0
+extern unsigned long g_mm_seqno;
+#endif
+
 /* User heap structure:
  *
  * - Flat build:  In the FLAT build, the user heap structure is a globally
@@ -249,7 +256,7 @@ FAR void *kmm_zalloc(size_t size) malloc_like1(1);
 /* Functions contained in kmm_memdump.c *************************************/
 
 #ifdef CONFIG_MM_KERNEL_HEAP
-void kmm_memdump(pid_t pid);
+void kmm_memdump(FAR const struct mm_memdump_s *dump);
 #endif
 
 /* Functions contained in mm_memalign.c *************************************/
@@ -308,24 +315,23 @@ void kmm_extend(FAR void *mem, size_t size, int region);
 
 /* Functions contained in mm_mallinfo.c *************************************/
 
-struct mallinfo; /* Forward reference */
-int mm_mallinfo(FAR struct mm_heap_s *heap, FAR struct mallinfo *info);
-struct mallinfo_task; /* Forward reference */
-int mm_mallinfo_task(FAR struct mm_heap_s *heap,
-                     FAR struct mallinfo_task *info);
+struct mallinfo mm_mallinfo(FAR struct mm_heap_s *heap);
+struct mallinfo_task mm_mallinfo_task(FAR struct mm_heap_s *heap,
+                                      FAR const struct malltask *task);
 
 /* Functions contained in kmm_mallinfo.c ************************************/
 
 #ifdef CONFIG_MM_KERNEL_HEAP
 struct mallinfo kmm_mallinfo(void);
 #  if CONFIG_MM_BACKTRACE >= 0
-struct mallinfo_task kmm_mallinfo_task(pid_t pid);
+struct mallinfo_task kmm_mallinfo_task(FAR const struct malltask *task);
 #  endif
 #endif
 
 /* Functions contained in mm_memdump.c **************************************/
 
-void mm_memdump(FAR struct mm_heap_s *heap, pid_t pid);
+void mm_memdump(FAR struct mm_heap_s *heap,
+                FAR const struct mm_memdump_s *dump);
 
 #ifdef CONFIG_DEBUG_MM
 /* Functions contained in mm_checkcorruption.c ******************************/
@@ -338,7 +344,7 @@ FAR void umm_checkcorruption(void);
 
 /* Functions contained in umm_memdump.c *************************************/
 
-void umm_memdump(pid_t pid);
+void umm_memdump(FAR const struct mm_memdump_s *dump);
 
 /* Functions contained in kmm_checkcorruption.c *****************************/
 
