@@ -77,6 +77,26 @@
 #define IP_PROTO_UDP      17
 #define IP_PROTO_ICMP6    58
 
+/* Values for the TOS field */
+
+#define IPTOS_TOS_MASK    0x1e
+#define IPTOS_TOS(tos)    ((tos) & IPTOS_TOS_MASK)
+#define	IPTOS_LOWDELAY    0x10
+#define	IPTOS_THROUGHPUT  0x08
+#define	IPTOS_RELIABILITY 0x04
+#define	IPTOS_MINCOST     0x02
+
+#define IPTOS_PREC_MASK            0xe0
+#define IPTOS_PREC(tos)            ((tos) & IPTOS_PREC_MASK)
+#define IPTOS_PREC_NETCONTROL      0xe0
+#define IPTOS_PREC_INTERNETCONTROL 0xc0
+#define IPTOS_PREC_CRITIC_ECP      0xa0
+#define IPTOS_PREC_FLASHOVERRIDE   0x80
+#define IPTOS_PREC_FLASH           0x60
+#define IPTOS_PREC_IMMEDIATE       0x40
+#define IPTOS_PREC_PRIORITY        0x20
+#define IPTOS_PREC_ROUTINE         0x00
+
 /* Flag bits in 16-bit flags + fragment offset IPv4 header field */
 
 #define IP_FLAG_RESERVED  0x8000
@@ -217,6 +237,8 @@ struct ipv6_stats_s
   net_stats_t sent;       /* Number of sent packets at the IP layer */
   net_stats_t vhlerr;     /* Number of packets dropped due to wrong
                            * IP version or header length */
+  net_stats_t fragerr;    /* Number of packets dropped since they
+                           * were IP fragments */
   net_stats_t protoerr;   /* Number of packets dropped since they
                            * were neither ICMP, UDP nor TCP */
 };
