@@ -119,24 +119,6 @@
                                    * Non-IP Data Delivery
                                    */
 
-/* Internet protocol type: IP
- * deprecated. Use LTE_IPTYPE_V4 instead.
- */
-
-#define LTE_APN_IPTYPE_IP     LTE_IPTYPE_V4
-
-/* Internet protocol type: IPv6
- * deprecated. Use LTE_IPTYPE_V6 instead.
- */
-
-#define LTE_APN_IPTYPE_IPV6   LTE_IPTYPE_V6
-
-/* Internet protocol type: IPv4/v6
- * deprecated. Use LTE_IPTYPE_V4V6 instead.
- */
-
-#define LTE_APN_IPTYPE_IPV4V6 LTE_IPTYPE_V4V6
-
 #define LTE_APN_AUTHTYPE_NONE (0) /* PPP authentication type: NONE */
 #define LTE_APN_AUTHTYPE_PAP  (1) /* PPP authentication type: PAP */
 #define LTE_APN_AUTHTYPE_CHAP (2) /* PPP authentication type: CHAP */
@@ -213,18 +195,6 @@
 
 #define LTE_VER_NP_PACKAGE_LEN (32)
 
-/* Enable setting of PIN lock
- * deprecated. Use LTE_ENABLE instead.
- */
-
-#define LTE_PIN_ENABLE  LTE_ENABLE
-
-/* Disable setting of PIN lock
- * deprecated. Use LTE_DISABLE instead.
- */
-
-#define LTE_PIN_DISABLE LTE_DISABLE
-
 /* PIN status: Not pending for any password */
 
 #define LTE_PINSTAT_READY         (0)
@@ -333,18 +303,6 @@
 #define LTE_MCC_DIGIT     (3)  /* Digit number of Mobile Country Code */
 #define LTE_MNC_DIGIT_MAX (3)  /* Max digit number of Mobile Network Code */
 
-/* Digit number of mcc
- * deprecated. Use LTE_MCC_DIGIT instead.
- */
-
-#define LTE_CELLINFO_MCC_DIGIT     LTE_MCC_DIGIT
-
-/* Max digit number of mnc
- * deprecated. Use LTE_MNC_DIGIT_MAX instead.
- */
-
-#define LTE_CELLINFO_MNC_DIGIT_MAX LTE_MNC_DIGIT_MAX
-
 #define LTE_EDRX_ACTTYPE_WBS1     (0) /* E-UTRAN (WB-S1 mode)   */
 #define LTE_EDRX_ACTTYPE_NBS1     (1) /* E-UTRAN (NB-S1 mode)   */
 #define LTE_EDRX_ACTTYPE_ECGSMIOT (2) /* EC-GSM-IoT (A/Gb mode) */
@@ -485,6 +443,10 @@
 
 #define LTE_RESTART_MODEM_INITIATED (1)
 
+/* Modem restart cause: Modem firmware version error */
+
+#define LTE_RESTART_VERSION_ERROR   (2)
+
 /* Error indicator for error code */
 
 #define LTE_ERR_INDICATOR_ERRCODE  (0x01)
@@ -525,18 +487,6 @@
 
 #define LTE_SIMINFO_GETOPT_GID2   (1 << 5)
 
-/* Digit number of mcc
- * deprecated. Use LTE_MCC_DIGIT instead.
- */
-
-#define LTE_SIMINFO_MCC_DIGIT      LTE_MCC_DIGIT
-
-/* Max digit number of mnc
- * deprecated. Use LTE_MNC_DIGIT_MAX instead.
- */
-
-#define LTE_SIMINFO_MNC_DIGIT_MAX  LTE_MNC_DIGIT_MAX
-
 #define LTE_SIMINFO_SPN_LEN   (16)  /* Maximum length of SPN */
 #define LTE_SIMINFO_ICCID_LEN (10)  /* Maximum length of ICCCID */
 #define LTE_SIMINFO_IMSI_LEN  (15)  /* Maximum length of IMSI */
@@ -2042,4 +1992,16 @@ typedef void (*get_current_psm_cb_t)(uint32_t result,
 typedef void (*get_quality_cb_t)(uint32_t result,
                                  lte_quality_t *quality);
 
+/* Definition of callback function.
+ *
+ * This callback function is used for nitifying a daemon
+ * context data for resume.
+ *
+ * [in] data : Context data body.
+ *
+ * [in] size : Context data size
+ */
+
+typedef void (*context_save_cb_t)(uint8_t *data, int size);
+
 #endif /* __INCLUDE_NUTTX_WIRELESS_LTE_LTE_H */
