@@ -410,7 +410,7 @@ struct boardioc_boot_info_s
 };
 #endif
 
-#ifdef CONFIG_BOARDCTL_RESET_CAUSE
+#if defined(CONFIG_BOARDCTL_RESET) || defined(CONFIG_BOARDCTL_RESET_CAUSE)
 /* Describes the reason of last reset */
 
 enum boardioc_reset_cause_e
@@ -434,10 +434,12 @@ enum boardioc_reset_cause_e
 enum boardioc_softreset_subreason_e
 {
   BOARDIOC_SOFTRESETCAUSE_USER_REBOOT = 0,
-  BOARDIOC_SOFTRESETCAUSE_PANIC,
   BOARDIOC_SOFTRESETCAUSE_ASSERT,
+  BOARDIOC_SOFTRESETCAUSE_PANIC,
+  BOARDIOC_SOFTRESETCAUSE_ENTER_BOOTLOADER,
   BOARDIOC_SOFTRESETCAUSE_ENTER_RECOVERY,
-  BOARDIOC_SOFTRESETCAUSE_RESTORE_FACTORY
+  BOARDIOC_SOFTRESETCAUSE_RESTORE_FACTORY,
+  BOARDIOC_SOFTRESETCAUSE_RESTORE_FACTORY_INQUIRY
 };
 
 struct boardioc_reset_cause_s
