@@ -149,6 +149,23 @@ int poll_fdsetup(int fd, FAR struct pollfd *fds, bool setup);
 void poll_default_cb(FAR struct pollfd *fds);
 void poll_notify(FAR struct pollfd **afds, int nfds, pollevent_t eventset);
 
+#if CONFIG_FORTIFY_SOURCE > 0
+fortify_function(poll) int poll(FAR struct pollfd *fds,
+                                nfds_t nfds, int timeout)
+{
+  fortify_assert(nfds <= fortify_size(fds, 0) / sizeof(struct pollfd));
+  return __real_poll(fds, nfds, timeout);
+}
+
+fortify_function(ppoll) int ppoll(FAR struct pollfd *fds, nfds_t nfds,
+                                  FAR const struct timespec *timeout_ts,
+                                  FAR const sigset_t *sigmask)
+{
+  fortify_assert(nfds <= fortify_size(fds, 0) / sizeof(struct pollfd));
+  return __real_ppoll(fds, nfds, timeout_ts, sigmask);
+}
+#endif
+
 #undef EXTERN
 #if defined(__cplusplus)
 }
