@@ -30,7 +30,6 @@
 #include <debug.h>
 #include <assert.h>
 
-#include <arch/elf.h>
 #include <nuttx/elf.h>
 
 /****************************************************************************
@@ -564,6 +563,11 @@ int up_relocateadd(const Elf_Rela *rel, const Elf_Sym *sym,
           *(uint64_t *)addr += (uint64_t)(sym->st_value + rel->r_addend);
         }
         break;
+      case R_RISCV_SUB16:
+        {
+          *(uint16_t *)addr -= (uint16_t)(sym->st_value + rel->r_addend);
+        }
+        break;
       case R_RISCV_SUB32:
         {
           *(uint32_t *)addr -= (uint32_t)(sym->st_value + rel->r_addend);
@@ -574,6 +578,11 @@ int up_relocateadd(const Elf_Rela *rel, const Elf_Sym *sym,
           *(uint64_t *)addr -= (uint64_t)(sym->st_value + rel->r_addend);
         }
         break;
+      case R_RISCV_SET16:
+        {
+          *(uint16_t *)addr = (uint16_t)(sym->st_value + rel->r_addend);
+        }
+        break;
       default:
         berr("ERROR: Unsupported relocation: %ld\n",
              ARCH_ELF_RELTYPE(rel->r_info));
