@@ -87,9 +87,6 @@
 
 #define MARK(a) { asm(" .globl M.a"); asm("M.a:"); }
 
-#undef min
-#define min(a,b) ((a>b) ? b : a)
-
 #ifndef IBUFSIZ
 #  define IBUFSIZ BUFSIZ        /* Defailt input buffer size */
 #endif
