@@ -58,6 +58,8 @@
 #include <assert.h>
 #include <errno.h>
 
+#include <sys/param.h>
+
 #include <nuttx/time.h>
 #include <nuttx/init.h>
 #include <nuttx/fs/fs.h>
@@ -120,7 +122,6 @@
 /* Unlike <ctype.h>'s isdigit, this also works if c < 0 | c > UCHAR_MAX. */
 
 #define is_digit(c)         ((unsigned)(c) - '0' <= 9)
-#define BIGGEST(a, b)       (((a) > (b)) ? (a) : (b))
 #define MY_TZNAME_MAX       255
 
 /* Max and min values of the integer type T, of which only the bottom
@@ -150,7 +151,7 @@
  * for ttunspecified to work without crashing.
  */
 
-#define CHARS_EXTRA         (BIGGEST(sizeof(UNSPEC), 2) - 1)
+#define CHARS_EXTRA         (MAX(sizeof(UNSPEC), 2) - 1)
 
 #define JULIAN_DAY            0  /* Jn = Julian day */
 #define DAY_OF_YEAR           1  /* n = day of year */
@@ -268,7 +269,7 @@ struct state_s
   time_t ats[TZ_MAX_TIMES];
   unsigned char types[TZ_MAX_TIMES];
   struct ttinfo_s ttis[TZ_MAX_TYPES];
-  char chars[BIGGEST(BIGGEST(TZ_MAX_CHARS + CHARS_EXTRA, sizeof("UTC")),
+  char chars[MAX(MAX(TZ_MAX_CHARS + CHARS_EXTRA, sizeof("UTC")),
                     (2 * (MY_TZNAME_MAX + 1)))];
   struct lsinfo_s lsis[TZ_MAX_LEAPS];
 
@@ -623,7 +624,7 @@ static int tzload(FAR const char *name,
       size_t namelen = strlen(name);
       const char tzdirslash[sizeof(TZDIR)] = TZDIR "/";
 
-      if (sizeof(fullname) - sizeof(tzdirslash) <= namelen)
+      if (sizeof(lsp->fullname) - sizeof(tzdirslash) <= namelen)
         {
           goto oops;
         }
@@ -634,7 +635,8 @@ static int tzload(FAR const char *name,
        */
 
       memcpy(fullname, tzdirslash, sizeof(tzdirslash));
-      strcpy(fullname + sizeof(tzdirslash), name);
+      strlcpy(fullname + sizeof(tzdirslash), name,
+              sizeof(lsp->fullname) - sizeof(tzdirslash));
 
       /* Set doaccess if NAME contains a ".." file name
        * component, as such a name could read a file outside
@@ -946,7 +948,7 @@ static int tzload(FAR const char *name,
 
                   if (j + tsabbrlen < TZ_MAX_CHARS)
                     {
-                      strcpy(sp->chars + j, tsabbr);
+                      strlcpy(sp->chars + j, tsabbr, sizeof(sp->chars) - j);
                       charcnt = j + tsabbrlen + 1;
                       ts->ttis[i].tt_desigidx = j;
                       gotabbr++;
@@ -2720,7 +2722,7 @@ static int zoneinit(FAR const char *name)
       g_lcl_ptr->goback  = 0;
       g_lcl_ptr->goahead = 0;
       init_ttinfo(&g_lcl_ptr->ttis[0], 0, FALSE, 0);
-      strcpy(g_lcl_ptr->chars, g_utc);
+      strlcpy(g_lcl_ptr->chars, g_utc, sizeof(g_lcl_ptr->chars));
       g_lcl_ptr->defaulttype = 0;
       return 0;
     }
@@ -2791,7 +2793,7 @@ void tzset(void)
       zoneinit("");
     }
 
-  strcpy(g_lcl_tzname, name);
+  strlcpy(g_lcl_tzname, name, sizeof(g_lcl_tzname));
 
 tzname:
   settzname();
