@@ -76,6 +76,7 @@
        { \
          FAR struct mm_allocnode_s *tmp = (FAR struct mm_allocnode_s *)(ptr); \
          tmp->pid = _SCHED_GETTID(); \
+         tmp->seqno = g_mm_seqno++; \
        } \
      while (0)
 #elif CONFIG_MM_BACKTRACE > 0
@@ -98,6 +99,7 @@
            { \
              tmp->backtrace[0] = NULL; \
            } \
+         tmp->seqno = g_mm_seqno++; \
        } \
      while (0)
 #else
@@ -127,9 +129,9 @@
 #define MM_PREVFREE_BIT  0x2
 #define MM_MASK_BIT      (MM_ALLOC_BIT | MM_PREVFREE_BIT)
 #ifdef CONFIG_MM_SMALL
-# define MMSIZE_MAX      UINT16_MAX
+#  define MMSIZE_MAX     UINT16_MAX
 #else
-# define MMSIZE_MAX      UINT32_MAX
+#  define MMSIZE_MAX     UINT32_MAX
 #endif
 
 /* What is the size of the allocnode? */
@@ -170,6 +172,7 @@ struct mm_allocnode_s
   mmsize_t size;                            /* Size of this chunk */
 #if CONFIG_MM_BACKTRACE >= 0
   pid_t pid;                                /* The pid for caller */
+  unsigned long seqno;                      /* The sequence of memory malloc */
 #  if CONFIG_MM_BACKTRACE > 0
   FAR void *backtrace[CONFIG_MM_BACKTRACE]; /* The backtrace buffer for caller */
 #  endif
@@ -184,6 +187,7 @@ struct mm_freenode_s
   mmsize_t size;                            /* Size of this chunk */
 #if CONFIG_MM_BACKTRACE >= 0
   pid_t pid;                                /* The pid for caller */
+  unsigned long seqno;                      /* The sequence of memory malloc */
 #  if CONFIG_MM_BACKTRACE > 0
   FAR void *backtrace[CONFIG_MM_BACKTRACE]; /* The backtrace buffer for caller */
 #  endif
