@@ -82,7 +82,7 @@ int can_getsockopt(FAR struct socket *psock, int level, int option,
 
   DEBUGASSERT(psock != NULL && value != NULL && value_len != NULL &&
               psock->s_conn != NULL);
-  conn = (FAR struct can_conn_s *)psock->s_conn;
+  conn = psock->s_conn;
 
 #ifdef CONFIG_NET_TIMESTAMP
   if (level == SOL_SOCKET && option == SO_TIMESTAMP)
@@ -123,6 +123,7 @@ int can_getsockopt(FAR struct socket *psock, int level, int option,
         else
           {
             int count = conn->filter_count;
+            int i;
 
             if (*value_len < count * sizeof(struct can_filter))
               {
@@ -133,12 +134,10 @@ int can_getsockopt(FAR struct socket *psock, int level, int option,
                 *value_len = count * sizeof(struct can_filter);
               }
 
-            for (int i = 0; i < count; i++)
+            for (i = 0; i < count; i++)
               {
-                ((struct can_filter *)value)[i] = conn->filters[i];
+                ((FAR struct can_filter *)value)[i] = conn->filters[i];
               }
-
-            ret = OK;
           }
         break;
 
@@ -153,14 +152,13 @@ int can_getsockopt(FAR struct socket *psock, int level, int option,
              * to me in this case.
              */
 
-            ret              = -EINVAL;
+            ret = -EINVAL;
           }
         else
           {
-            FAR int32_t *loopback  = (FAR int32_t *)value;
-            *loopback              = conn->loopback;
-            *value_len             = sizeof(conn->loopback);
-            ret                    = OK;
+            FAR int32_t *loopback = (FAR int32_t *)value;
+            *loopback             = conn->loopback;
+            *value_len            = sizeof(conn->loopback);
           }
         break;
 
@@ -172,14 +170,13 @@ int can_getsockopt(FAR struct socket *psock, int level, int option,
              * to me in this case.
              */
 
-            ret              = -EINVAL;
+            ret = -EINVAL;
           }
         else
           {
             FAR int32_t *recv_own_msgs = (FAR int32_t *)value;
             *recv_own_msgs             = conn->recv_own_msgs;
             *value_len                 = sizeof(conn->recv_own_msgs);
-            ret                        = OK;
           }
         break;
 
@@ -192,14 +189,13 @@ int can_getsockopt(FAR struct socket *psock, int level, int option,
              * to me in this case.
              */
 
-            ret              = -EINVAL;
+            ret = -EINVAL;
           }
         else
           {
             FAR int32_t *fd_frames = (FAR int32_t *)value;
             *fd_frames             = conn->fd_frames;
             *value_len             = sizeof(conn->fd_frames);
-            ret                    = OK;
           }
         break;
 #endif
@@ -216,14 +212,13 @@ int can_getsockopt(FAR struct socket *psock, int level, int option,
              * to me in this case.
              */
 
-            ret              = -EINVAL;
+            ret = -EINVAL;
           }
         else
           {
             FAR int32_t *tx_deadline = (FAR int32_t *)value;
             *tx_deadline             = conn->tx_deadline;
             *value_len               = sizeof(conn->tx_deadline);
-            ret                      = OK;
           }
         break;
 #endif
