@@ -30,6 +30,7 @@
 #include <sys/types.h>
 #include <stdint.h>
 #include <assert.h>
+#include <netinet/icmp6.h>
 
 #include <nuttx/mm/iob.h>
 #include <nuttx/net/ip.h>
@@ -84,7 +85,6 @@ struct icmpv6_conn_s
   /* ICMPv6-specific content follows */
 
   uint16_t   id;       /* ICMPv6 ECHO request ID */
-  uint8_t    nreqs;    /* Number of requests with no response received */
   uint8_t    crefs;    /* Reference counts on this instance */
 
   /* The device that the ICMPv6 request was sent on */
@@ -97,6 +97,7 @@ struct icmpv6_conn_s
    */
 
   struct iob_queue_s readahead;  /* Read-ahead buffering */
+  struct icmp6_filter filter;    /* ICMP6 type filter */
 
   /* The following is a list of poll structures of threads waiting for
    * socket events.
@@ -104,6 +105,11 @@ struct icmpv6_conn_s
 
   struct icmpv6_poll_s pollinfo[CONFIG_NET_ICMPv6_NPOLLWAITERS];
 };
+
+/* Callback from icmpv6_foreach() */
+
+typedef CODE int (*icmpv6_callback_t)(FAR struct icmpv6_conn_s *conn,
+                                      FAR void *arg);
 #endif
 
 #ifdef CONFIG_NET_ICMPv6_NEIGHBOR
@@ -130,6 +136,13 @@ struct icmpv6_rnotify_s
 };
 #endif
 
+struct icmpv6_pmtu_entry
+{
+  net_ipv6addr_t daddr;
+  uint16_t pmtu;
+  clock_t time;
+};
+
 /****************************************************************************
  * Public Data
  ****************************************************************************/
@@ -596,11 +609,12 @@ FAR struct icmpv6_conn_s *icmpv6_nextconn(FAR struct icmpv6_conn_s *conn);
 #endif
 
 /****************************************************************************
- * Name: icmpv6_findconn
+ * Name: icmpv6_foreach
  *
  * Description:
- *   Find an ICMPv6 connection structure that is expecting a ICMPv6 ECHO
- *   response with this ID from this device
+ *   Enumerate each ICMPv6 connection structure. This function will terminate
+ *   when either (1) all connection have been enumerated or (2) when a
+ *   callback returns any non-zero value.
  *
  * Assumptions:
  *   This function is called from network logic at with the network locked.
@@ -608,8 +622,7 @@ FAR struct icmpv6_conn_s *icmpv6_nextconn(FAR struct icmpv6_conn_s *conn);
  ****************************************************************************/
 
 #ifdef CONFIG_NET_ICMPv6_SOCKET
-FAR struct icmpv6_conn_s *icmpv6_findconn(FAR struct net_driver_s *dev,
-                                          uint16_t id);
+int icmpv6_foreach(icmpv6_callback_t callback, FAR void *arg);
 #endif
 
 /****************************************************************************
@@ -645,7 +658,7 @@ ssize_t icmpv6_sendmsg(FAR struct socket *psock, FAR struct msghdr *msg,
  * Description:
  *   Implements the socket recvfrom interface for the case of the AF_INET
  *   data gram socket with the IPPROTO_ICMP6 protocol.  icmpv6_recvmsg()
- *   receives ICMPv6 ECHO replies for the a socket.
+ *   receives ICMPv6 message for the a socket.
  *
  *   If msg_name is not NULL, and the underlying protocol provides the source
  *   address, this source address is filled in. The argument 'msg_namelen' is
@@ -777,6 +790,39 @@ void icmpv6_reply(FAR struct net_driver_s *dev,
 int icmpv6_ioctl(FAR struct socket *psock, int cmd, unsigned long arg);
 #endif
 
+/****************************************************************************
+ * Name: icmpv6_find_pmtu_entry
+ *
+ * Description:
+ *   Search for a ipv6 pmtu entry
+ *
+ * Parameters:
+ *   destipaddr   the IPv6 address of the destination
+ *
+ * Return:
+ *   void
+ ****************************************************************************/
+
+FAR struct icmpv6_pmtu_entry *
+icmpv6_find_pmtu_entry(net_ipv6addr_t destipaddr);
+
+/****************************************************************************
+ * Name: icmpv6_add_pmtu_entry
+ *
+ * Description:
+ *   Create a new ipv6 destination cache entry. If no unused entry is found,
+ *   will recycle oldest entry
+ *
+ * Parameters:
+ *   destipaddr   the IPv6 address of the destination
+ *   mtu          MTU
+ *
+ * Return:
+ *   void
+ ****************************************************************************/
+
+void icmpv6_add_pmtu_entry(net_ipv6addr_t destipaddr, int mtu);
+
 #undef EXTERN
 #ifdef __cplusplus
 }
