@@ -454,10 +454,11 @@ static void tcp_input_ofosegs(FAR struct net_driver_s *dev,
   /* Trim l3/l4 header to reserve appdata */
 
   dev->d_iob = iob_trimhead(dev->d_iob, len);
-  if (dev->d_iob == NULL)
+  if (dev->d_iob == NULL || dev->d_iob->io_pktlen == 0)
     {
       /* No available data, clear device buffer */
 
+      iob_free_chain(dev->d_iob);
       goto clear;
     }
 
@@ -586,6 +587,13 @@ static void tcp_parse_option(FAR struct net_driver_s *dev,
 
           tmp16 = ((uint16_t)IPDATA(tcpiplen + 2 + i) << 8) |
                    (uint16_t)IPDATA(tcpiplen + 3 + i);
+#ifdef CONFIG_NET_TCPPROTO_OPTIONS
+          if (conn->user_mss > 0 && conn->user_mss < tcp_mss)
+            {
+              tcp_mss = conn->user_mss;
+            }
+#endif
+
           conn->mss = tmp16 > tcp_mss ? tcp_mss : tmp16;
         }
 #ifdef CONFIG_NET_TCP_WINDOW_SCALE
@@ -748,11 +756,17 @@ static void tcp_input(FAR struct net_driver_s *dev, uint8_t domain,
 #endif
 
 #if defined(CONFIG_NET_IPv4) && defined(CONFIG_NET_IPv6)
-      if (tcp_islistener(&uaddr, tmp16, domain))
+      if ((conn = tcp_findlistener(&uaddr, tmp16, domain)) != NULL)
 #else
-      if (tcp_islistener(&uaddr, tmp16))
+      if ((conn = tcp_findlistener(&uaddr, tmp16)) != NULL)
 #endif
         {
+          if (!tcp_backlogavailable(conn))
+            {
+              nerr("ERROR: no free containers for TCP BACKLOG!\n");
+              goto drop;
+            }
+
           /* We matched the incoming packet with a connection in LISTEN.
            * We now need to create a new connection and send a SYNACK in
            * response.
@@ -762,7 +776,7 @@ static void tcp_input(FAR struct net_driver_s *dev, uint8_t domain,
            * any user application to accept it.
            */
 
-          conn = tcp_alloc_accept(dev, tcp);
+          conn = tcp_alloc_accept(dev, tcp, conn);
           if (conn)
             {
               /* The connection structure was successfully allocated and has
@@ -1146,6 +1160,11 @@ found:
   if ((tcp->flags & TCP_ACK) != 0 &&
       (conn->tcpstateflags & TCP_STATE_MASK) != TCP_SYN_RCVD)
     {
+#ifdef CONFIG_NET_TCP_CC_NEWRENO
+      /* If the packet is ack, update the cc var. */
+
+      tcp_cc_recv_ack(conn, tcp);
+#endif
       if (tcp_snd_wnd_update(conn, tcp))
         {
           /* Window updated, set the acknowledged flag. */
@@ -1216,6 +1235,9 @@ found:
             tcp_snd_wnd_init(conn, tcp);
             tcp_snd_wnd_update(conn, tcp);
 
+#ifdef CONFIG_NET_TCP_CC_NEWRENO
+            tcp_cc_update(conn, tcp);
+#endif
             flags               = TCP_CONNECTED;
             ninfo("TCP state: TCP_ESTABLISHED\n");
 
@@ -1265,6 +1287,9 @@ found:
             tcp_snd_wnd_init(conn, tcp);
             tcp_snd_wnd_update(conn, tcp);
 
+#ifdef CONFIG_NET_TCP_CC_NEWRENO
+            tcp_cc_update(conn, tcp);
+#endif
             net_incr32(conn->rcvseq, 1); /* ack SYN */
             conn->tx_unacked    = 0;
 
