@@ -49,7 +49,6 @@
 #include <nuttx/net/net.h>
 #include <nuttx/mm/iob.h>
 #include <nuttx/net/netdev.h>
-#include <nuttx/net/arp.h>
 #include <nuttx/net/udp.h>
 
 #include "netdev/netdev.h"
@@ -407,7 +406,6 @@ static uint16_t sendto_eventhandler(FAR struct net_driver_s *dev,
     {
       uint16_t udpiplen = udpip_hdrsize(conn);
       FAR struct udp_wrbuffer_s *wrb;
-      size_t sndlen;
 
       /* Peek at the head of the write queue (but don't remove anything
        * from the write queue yet).  We know from the above test that
@@ -425,14 +423,20 @@ static uint16_t sendto_eventhandler(FAR struct net_driver_s *dev,
 
       udp_connect(conn, (FAR const struct sockaddr *)&wrb->wb_dest);
 
+      /* Then set-up to send that amount of data with the offset
+       * corresponding to the size of the IP-dependent address structure.
+       */
+
+      netdev_iob_replace(dev, wrb->wb_iob);
+
       /* Get the amount of data that we can send in the next packet.
        * We will send either the remaining data in the buffer I/O
        * buffer chain, or as much as will fit given the MSS and current
        * window size.
        */
 
-      sndlen = wrb->wb_iob->io_pktlen - udpiplen;
-      ninfo("wrb=%p sndlen=%zu\n", wrb, sndlen);
+      dev->d_sndlen = wrb->wb_iob->io_pktlen - udpiplen;
+      ninfo("wrb=%p sndlen=%d\n", wrb, dev->d_sndlen);
 
 #ifdef NEED_IPDOMAIN_SUPPORT
       /* If both IPv4 and IPv6 support are enabled, then we will need to
@@ -444,16 +448,6 @@ static uint16_t sendto_eventhandler(FAR struct net_driver_s *dev,
       sendto_ipselect(dev, conn);
 #endif
 
-      /* Release current device buffer and bypass the iob to l2 driver */
-
-      netdev_iob_release(dev);
-
-      /* Then set-up to send that amount of data with the offset
-       * corresponding to the size of the IP-dependent address structure.
-       */
-
-      devif_iob_send(dev, wrb->wb_iob, sndlen, 0, udpiplen);
-
       /* Free the write buffer at the head of the queue and attempt to
        * setup the next transfer.
        */
@@ -472,6 +466,34 @@ static uint16_t sendto_eventhandler(FAR struct net_driver_s *dev,
   return flags;
 }
 
+/****************************************************************************
+ * Name: udp_send_gettimeout
+ *
+ * Description:
+ *   Calculate the send timeout
+ *
+ ****************************************************************************/
+
+static unsigned int udp_send_gettimeout(clock_t start, unsigned int timeout)
+{
+  unsigned int elapse;
+
+  if (timeout != UINT_MAX)
+    {
+      elapse = TICK2MSEC(clock_systime_ticks() - start);
+      if (elapse >= timeout)
+        {
+          timeout = 0;
+        }
+      else
+        {
+          timeout -= elapse;
+        }
+    }
+
+  return timeout;
+}
+
 /****************************************************************************
  * Public Functions
  ****************************************************************************/
@@ -512,6 +534,7 @@ ssize_t psock_udp_sendto(FAR struct socket *psock, FAR const void *buf,
   bool nonblock;
   bool empty;
   int ret = OK;
+  clock_t start;
 
   /* Get the underlying the UDP connection structure.  */
 
@@ -636,6 +659,7 @@ ssize_t psock_udp_sendto(FAR struct socket *psock, FAR const void *buf,
 
   nonblock = _SS_ISNONBLOCK(conn->sconn.s_flags) ||
                             (flags & MSG_DONTWAIT) != 0;
+  start    = clock_systime_ticks();
   timeout  = _SO_TIMEOUT(conn->sconn.s_sndtimeo);
 
   /* Dump the incoming buffer */
@@ -659,7 +683,8 @@ ssize_t psock_udp_sendto(FAR struct socket *psock, FAR const void *buf,
               goto errout_with_lock;
             }
 
-          ret = net_timedwait_uninterruptible(&conn->sndsem, timeout);
+          ret = net_sem_timedwait_uninterruptible(&conn->sndsem,
+            udp_send_gettimeout(start, timeout));
           if (ret < 0)
             {
               if (ret == -ETIMEDOUT)
@@ -682,7 +707,8 @@ ssize_t psock_udp_sendto(FAR struct socket *psock, FAR const void *buf,
         }
       else
         {
-          wrb = udp_wrbuffer_timedalloc(timeout);
+          wrb = udp_wrbuffer_timedalloc(udp_send_gettimeout(start,
+                                                            timeout));
         }
 
       if (wrb == NULL)
