@@ -95,7 +95,7 @@ int udp_txdrain(FAR struct socket *psock, unsigned int timeout)
   DEBUGASSERT(psock != NULL && psock->s_conn != NULL);
   DEBUGASSERT(psock->s_type == SOCK_DGRAM);
 
-  conn = (FAR struct udp_conn_s *)psock->s_conn;
+  conn = psock->s_conn;
 
   /* Initialize the wait semaphore */
 
