@@ -36,6 +36,7 @@
 #include <nuttx/fs/fs.h>
 #include <nuttx/net/net.h>
 #include <nuttx/mm/iob.h>
+#include <nuttx/mm/kmap.h>
 #include <nuttx/mm/mm.h>
 #include <nuttx/kmalloc.h>
 #include <nuttx/pgalloc.h>
@@ -376,7 +377,8 @@ void nx_start(void)
        * the IDLE task.
        */
 
-      g_idletcb[i].cmn.affinity = SCHED_ALL_CPUS;
+      g_idletcb[i].cmn.affinity =
+        (cpu_set_t)(CONFIG_SMP_DEFAULT_CPUSET & SCHED_ALL_CPUS);
 #else
       g_idletcb[i].cmn.flags = (TCB_FLAG_TTYPE_KERNEL |
                                 TCB_FLAG_NONCANCELABLE);
@@ -471,6 +473,12 @@ void nx_start(void)
     }
 #endif
 
+#ifdef CONFIG_MM_KMAP
+  /* Initialize the kernel dynamic mapping module */
+
+  kmm_map_initialize();
+#endif
+
 #ifdef CONFIG_ARCH_HAVE_EXTRA_HEAPS
   /* Initialize any extra heap. */
 
