@@ -73,9 +73,11 @@ void nxsem_wait_irq(FAR struct tcb_s *wtcb, int errcode)
   FAR sem_t *sem = wtcb->waitobj;
 
 #ifdef CONFIG_ARCH_ADDRENV
+  FAR struct addrenv_s *oldenv;
+
   if (wtcb->addrenv_own)
     {
-      addrenv_select(wtcb->addrenv_own);
+      addrenv_select(wtcb->addrenv_own, &oldenv);
     }
 #endif
 
@@ -106,7 +108,7 @@ void nxsem_wait_irq(FAR struct tcb_s *wtcb, int errcode)
 #ifdef CONFIG_ARCH_ADDRENV
   if (wtcb->addrenv_own)
     {
-      addrenv_restore();
+      addrenv_restore(oldenv);
     }
 #endif
 
